@@ -3,7 +3,7 @@
 
 #include <wx/string.h>
 #include <wx/file.h>
-
+#include <wx/arrstr.h>
 
 class ChatLog
 {
@@ -14,6 +14,7 @@ class ChatLog
     bool LogEnabled();
     wxString LogTime();
     void OpenInEditor();
+    const wxArrayString& GetLastLines( ) const;
 //    void SetTarget( const wxString& server,const wxString& room );
   protected:
     bool CreateFolder(const wxString& server);
@@ -26,7 +27,9 @@ class ChatLog
     wxString m_current_logfile_path;
     bool m_active;
     static bool m_parent_dir_exists;
+    wxArrayString m_last_lines;
 
+    void FillLastLineArray();
 
 };
 
