@@ -13,7 +13,6 @@
 #include "settings.h"
 #include "ui.h"
 #include "springunitsynclib.h"
-#include "images/fixcolours_palette.xpm"
 
 #include <list>
 #include <algorithm>
@@ -27,6 +26,7 @@ IBattle::IBattle():
   m_mod_loaded(false),
   m_map_exists(false),
   m_mod_exists(false),
+  m_previous_local_mod_name( wxEmptyString ),
   m_ingame(false),
   m_generating_script(false),
 	m_players_ready(0),
@@ -55,41 +55,19 @@ bool IBattle::IsSynced()
     return synced;
 }
 
-
-
-
-
-std::vector<wxColour> &IBattle::GetFixColoursPalette( int numteams )
+std::vector<wxColour> &IBattle::GetFixColoursPalette( int numteams ) const
 {
-    static std::vector<wxColour> result;
-    if (result.empty())
-    {
-        wxImage image(fixcolours_palette_xpm);
-        unsigned char* data=image.GetData();
-        size_t len=image.GetWidth()*image.GetHeight();
-        for (size_t i=0;i<len;++i)
-        {
-            int r=data[i*3];
-            int g=data[i*3+1];
-            int b=data[i*3+2];
-            if (r||g||b)
-            {
-                result.push_back(wxColour(r,g,b));
-            }
-        }
-    }
-    if ( result.size() > numteams ) return result;
     return GetBigFixColoursPalette( numteams );
 }
 
-wxColour IBattle::GetFixColour(int i)
+wxColour IBattle::GetFixColour(int i) const
 {
 		int size = m_teams_sizes.size();
     std::vector<wxColour> palette = GetFixColoursPalette( size );
 		return palette[i];
 }
 
-int IBattle::GetPlayerNum( const User& user )
+int IBattle::GetPlayerNum( const User& user ) const
 {
     for (user_map_t::size_type i = 0; i < GetNumUsers(); i++)
     {
@@ -129,7 +107,7 @@ class AreColoursSimilarProxy {
         }
 };
 
-wxColour IBattle::GetFreeColour( User *for_whom )
+wxColour IBattle::GetFreeColour( User * ) const
 {
     typedef std::vector<wxColour>
         ColorVec;
@@ -153,24 +131,24 @@ wxColour IBattle::GetFreeColour( User *for_whom )
     }
 }
 
-wxColour IBattle::GetFreeColour( User &for_whom )
+wxColour IBattle::GetFreeColour( User &for_whom ) const
 {
     return GetFreeColour( &for_whom );
 }
 
 
-wxColour IBattle::GetNewColour()
+wxColour IBattle::GetNewColour() const
 {
     return GetFreeColour();
 }
 
-int IBattle::ColourDifference(const wxColour &a, const wxColour &b) // returns max difference of r,g,b.
+int IBattle::ColourDifference(const wxColour &a, const wxColour &b)  const// returns max difference of r,g,b.
 {
     return std::max(abs(a.Red()-b.Red()),std::max(abs(a.Green()-b.Green()),abs(a.Blue()-b.Blue())));
 
 }
 
-int IBattle::GetFreeTeamNum( bool excludeme )
+int IBattle::GetFreeTeam( bool excludeme )
 {
     int lowest = 0;
     bool changed = true;
@@ -179,9 +157,10 @@ int IBattle::GetFreeTeamNum( bool excludeme )
         changed = false;
         for ( user_map_t::size_type i = 0; i < GetNumUsers(); i++ )
         {
-            if ( ( &GetUser( i ) == &GetMe() ) && excludeme ) continue;
-            //if ( GetUser( i ).BattleStatus().spectator ) continue;
-            if ( GetUser( i ).BattleStatus().team == lowest )
+						User& user = GetUser( i );
+            if ( ( &user == &GetMe() ) && excludeme ) continue;
+            if ( user.BattleStatus().spectator ) continue;
+            if ( user.BattleStatus().team == lowest )
             {
                 lowest++;
                 changed = true;
@@ -191,7 +170,7 @@ int IBattle::GetFreeTeamNum( bool excludeme )
     return lowest;
 }
 
-int IBattle::GetClosestFixColour(const wxColour &col, const std::vector<int> &excludes, int difference)
+int IBattle::GetClosestFixColour(const wxColour &col, const std::vector<int> &excludes, int difference) const
 {
     std::vector<wxColour> palette = GetFixColoursPalette( m_teams_sizes.size() + 1 );
     int result=0;
@@ -233,7 +212,7 @@ User& IBattle::OnUserAdded( User& user )
     bs.sync = SYNC_UNKNOWN;
     if ( !bs.IsBot() && IsFounderMe() && GetBattleType() == BT_Played )
     {
-			bs.team = GetFreeTeamNum( &user == &GetMe() );
+			bs.team = GetFreeTeam( &user == &GetMe() );
 			bs.ally = GetFreeAlly( &user == &GetMe() );
 			bs.colour = GetFreeColour( user );
     }
@@ -245,14 +224,10 @@ User& IBattle::OnUserAdded( User& user )
     }
 		if ( !bs.spectator )
 		{
-			std::map<int, int>::iterator itor = m_teams_sizes.find( bs.team );
-			if ( itor == m_teams_sizes.end() ) m_teams_sizes[bs.team] = 1;
-			else m_teams_sizes[bs.team] = m_teams_sizes[bs.team] + 1;
-			std::map<int, int>::iterator iter = m_ally_sizes.find( bs.ally );
-			if ( iter == m_ally_sizes.end() ) m_ally_sizes[bs.ally] = 1;
-			else m_ally_sizes[bs.ally] = m_ally_sizes[bs.ally] + 1;
+			PlayerJoinedAlly( bs.ally );
+			PlayerJoinedTeam( bs.team );
 		}
-		if ( bs.spectator ) m_opts.spectators++;
+		if ( bs.spectator && IsFounderMe() ) m_opts.spectators++;
 		if ( bs.ready && !bs.IsBot() ) m_players_ready++;
 		if ( bs.sync && !bs.IsBot() ) m_players_sync++;
 		if ( !bs.spectator && !bs.IsBot() && ( !bs.ready || !bs.sync ) ) m_ready_up_map[user.GetNick()] = time(0);
@@ -265,10 +240,6 @@ User& IBattle::OnBotAdded( const wxString& nick, const UserBattleStatus& bs )
 		User& user = m_internal_bot_list[nick];
 		user.UpdateBattleStatus( bs );
 		User& usr = OnUserAdded( user );
-		if ( GetMe().GetNick() == bs.owner )
-		{
-			 if ( bs.aitype >= 0 ) OptionsWrapper().loadAIOptions( GetHostModName(), bs.aitype, nick );
-		}
 		return usr;
 }
 
@@ -289,6 +260,17 @@ void IBattle::OnUserBattleStatusUpdated( User &user, UserBattleStatus status )
 
     user.UpdateBattleStatus( status );
 
+		if ( !previousstatus.spectator )
+		{
+			PlayerLeftAlly( previousstatus.ally );
+			PlayerLeftTeam( previousstatus.team );
+		}
+		if ( !status.spectator )
+		{
+			PlayerJoinedAlly( status.ally );
+			PlayerJoinedTeam( status.team );
+		}
+
     if ( IsFounderMe() )
     {
 			if ( status.spectator != previousstatus.spectator )
@@ -303,85 +285,33 @@ void IBattle::OnUserBattleStatusUpdated( User &user, UserBattleStatus status )
 					}
 					SendHostInfo( HI_Spectators );
 			}
-			if ( m_opts.lockexternalbalancechanges )
-			{
-				if ( previousstatus.team != status.team ) ForceTeam( user, previousstatus.team );
-				if ( previousstatus.ally != status.ally ) ForceAlly( user, previousstatus.ally );
-			}
 	}
-	if ( status.spectator != previousstatus.spectator )
-	{
-		if ( !status.spectator )
-		{
-			std::map<int, int>::iterator itor = m_teams_sizes.find( status.team );
-			if ( itor == m_teams_sizes.end() ) m_teams_sizes[status.team] = 1;
-			else m_teams_sizes[status.team] = m_teams_sizes[status.team] + 1;
-			std::map<int, int>::iterator iter = m_ally_sizes.find( status.ally );
-			if ( iter == m_ally_sizes.end() ) m_ally_sizes[status.ally] = 1;
-			else m_ally_sizes[status.ally] = m_ally_sizes[status.ally] + 1;
-		}
-		else
-		{
-			std::map<int, int>::iterator itor = m_teams_sizes.find( status.team );
-			if ( itor != m_teams_sizes.end() )
-			{
-				 itor->second = itor->second -1;
-				if ( itor->second == 0 )
-				{
-					m_teams_sizes.erase( itor );
-				}
-			}
-			std::map<int, int>::iterator iter = m_ally_sizes.find( status.ally );
-			if ( iter != m_ally_sizes.end() )
-			{
-				iter->second = iter->second - 1;
-				if ( iter->second == 0 )
-				{
-					m_ally_sizes.erase( iter );
-				}
-			}
-		}
-	}
-	else
-	{
-		std::map<int, int>::iterator itor = m_teams_sizes.find( previousstatus.team );
-		if ( itor != m_teams_sizes.end() )
-		{
-			 itor->second = itor->second -1;
-			if ( itor->second == 0 )
-			{
-				m_teams_sizes.erase( itor );
-			}
-		}
-		itor = m_teams_sizes.find( status.team );
-		if ( itor != m_teams_sizes.end() ) itor->second = itor->second + 1;
-		else m_teams_sizes[status.team] = 1;
 
-		std::map<int, int>::iterator iter = m_ally_sizes.find( previousstatus.ally );
-		if ( iter != m_ally_sizes.end() )
-		{
-			 iter->second = iter->second - 1;
-				if ( iter->second == 0 )
-				{
-					m_ally_sizes.erase( iter );
-				}
-		}
-		iter = m_ally_sizes.find( status.ally );
-		if ( iter != m_ally_sizes.end() ) iter->second = iter->second + 1;
-		else m_ally_sizes[status.ally] = 1;
-	}
 	if ( !status.IsBot() )
 	{
-		if ( ( previousstatus.ready != status.ready ) && !status.spectator && !previousstatus.spectator )
+
+		if ( !previousstatus.spectator && !status.spectator && (  previousstatus.ready != status.ready ) )
 		{
 			 if ( status.ready ) m_players_ready++;
 			 else m_players_ready--;
 		}
-		if ( ( previousstatus.sync != status.sync ) && !status.spectator && !previousstatus.spectator )
+
+		if ( previousstatus.spectator ) // coming from spectator
+		{
+			 if ( status.ready ) m_players_ready++;
+		}
+
+		if ( status.spectator ) // becoming spectator
+		{
+			if ( previousstatus.ready ) m_players_ready--;
+		}
+
+		if ( ( previousstatus.sync != status.sync ) )
 		{
 			 if ( status.sync ) m_players_sync++;
 			 else m_players_sync--;
 		}
+
 		if ( ( status.ready && status.sync ) || status.spectator )
 		{
 			std::map<wxString, time_t>::iterator itor = m_ready_up_map.find( user.GetNick() );
@@ -401,7 +331,7 @@ void IBattle::OnUserBattleStatusUpdated( User &user, UserBattleStatus status )
 	}
 }
 
-bool IBattle::ShouldAutoStart()
+bool IBattle::ShouldAutoStart() const
 {
 	if ( GetInGame() ) return false;
 	if ( !IsLocked() && (  ( GetNumPlayers() - m_opts.spectators ) ) < m_opts.maxplayers ) return false; // proceed checking for ready players only if the battle is full or locked
@@ -417,51 +347,39 @@ bool IBattle::ShouldAutoStart()
 
 void IBattle::OnUserRemoved( User& user )
 {
-		UserBattleStatus& bs = user.BattleStatus();
-		if ( !bs.spectator )
-		{
-			std::map<int, int>::iterator itor = m_teams_sizes.find( bs.team );
-			if ( itor != m_teams_sizes.end() )
-			{
-				 itor->second = itor->second -1;
-				if ( itor->second == 0 )
-				{
-					m_teams_sizes.erase( itor );
-				}
-			}
-			std::map<int, int>::iterator iter = m_ally_sizes.find( bs.ally );
-			if ( iter != m_ally_sizes.end() )
-			{
-				iter->second = iter->second - 1;
-				if ( iter->second == 0 )
-				{
-					m_ally_sizes.erase( iter );
-				}
-			}
- 		}
-		if ( bs.ready && !bs.IsBot() ) m_players_ready--;
-		if ( bs.sync && !bs.IsBot() ) m_players_sync--;
+    UserBattleStatus& bs = user.BattleStatus();
+    if ( !bs.spectator )
+    {
+        PlayerLeftTeam( bs.team );
+        PlayerLeftAlly( bs.ally );
+    }
+    if ( bs.ready && !bs.IsBot() )
+        m_players_ready--;
+    if ( bs.sync && !bs.IsBot() )
+        m_players_sync--;
     if ( IsFounderMe() && bs.spectator )
     {
-      m_opts.spectators--;
-      SendHostInfo( HI_Spectators );
+        m_opts.spectators--;
+        SendHostInfo( HI_Spectators );
     }
     if ( &user == &GetMe() )
     {
-    	 if ( m_timer ) m_timer->Stop();
-    	 delete m_timer;
-    	 m_timer = 0;
-    	 OnSelfLeftBattle();
+        if ( m_timer )
+            m_timer->Stop();
+        delete m_timer;
+        m_timer = 0;
+        OnSelfLeftBattle();
     }
     UserList::RemoveUser( user.GetNick() );
-    if ( !bs.IsBot() ) user.SetBattle( 0 );
+    if ( !bs.IsBot() )
+        user.SetBattle( 0 );
     else
     {
     	UserVecIter itor = m_internal_bot_list.find( user.GetNick() );
-			if ( itor != m_internal_bot_list.end() )
-			{
-    			m_internal_bot_list.erase( itor );
-			}
+        if ( itor != m_internal_bot_list.end() )
+        {
+            m_internal_bot_list.erase( itor );
+        }
     }
 }
 
@@ -470,9 +388,8 @@ bool IBattle::IsEveryoneReady()
 {
     for (user_map_t::size_type i = 0; i < GetNumUsers(); i++)
     {
-				User& usr = GetUser(i);
-				if ( usr.BattleStatus().IsBot() ) continue;
-        UserBattleStatus& bs = usr.BattleStatus();
+		UserBattleStatus& bs = GetUser(i).BattleStatus();
+		if ( bs.IsBot() ) continue;
         if ( !bs.ready && !bs.spectator ) return false;
     }
     return true;
@@ -561,22 +478,22 @@ void IBattle::StartRectAdded( unsigned int allyno )
 }
 
 
-BattleStartRect IBattle::GetStartRect( unsigned int allyno )
+BattleStartRect IBattle::GetStartRect( unsigned int allyno ) const
 {
-	std::map<unsigned int,BattleStartRect>::iterator rect_it = m_rects.find(allyno);
+	std::map<unsigned int,BattleStartRect>::const_iterator rect_it = m_rects.find(allyno);
 	if( rect_it != m_rects.end() )
 		return (*rect_it).second;
 	return BattleStartRect();
 }
 
 //total number of start rects
-unsigned int IBattle::GetNumRects()
+unsigned int IBattle::GetNumRects() const
 {
     return m_rects.size();
 }
 
 //key of last start rect in the map
-unsigned int IBattle::GetLastRectIdx()
+unsigned int IBattle::GetLastRectIdx() const
 {
 	if(GetNumRects() > 0)
 		return m_rects.rbegin()->first;
@@ -586,7 +503,7 @@ unsigned int IBattle::GetLastRectIdx()
 }
 
 //return  the lowest currently unused key in the map of rects.
-unsigned int IBattle::GetNextFreeRectIdx()
+unsigned int IBattle::GetNextFreeRectIdx() const
 {
 	//check for unused allyno keys
 	for(unsigned int i = 0; i <= GetLastRectIdx(); i++)
@@ -616,18 +533,8 @@ void IBattle::ForceTeam( User& user, int team )
   {
 		if ( !user.BattleStatus().spectator )
 		{
-			std::map<int, int>::iterator itor = m_teams_sizes.find( user.BattleStatus().ally );
-			if ( itor != m_teams_sizes.end() )
-			{
-				 itor->second = itor->second -1;
-				if ( itor->second == 0 )
-				{
-					m_teams_sizes.erase( itor );
-				}
-			}
-			itor = m_teams_sizes.find( team );
-			if ( itor != m_teams_sizes.end() ) itor->second = itor->second + 1;
-			else m_teams_sizes[team] = 1;
+			PlayerLeftTeam( user.BattleStatus().team );
+			PlayerJoinedTeam( team );
 		}
 		user.BattleStatus().team = team;
   }
@@ -641,18 +548,8 @@ void IBattle::ForceAlly( User& user, int ally )
   {
 		if ( !user.BattleStatus().spectator )
 		{
-			std::map<int, int>::iterator itor = m_ally_sizes.find( user.BattleStatus().ally );
-			if ( itor != m_ally_sizes.end() )
-			{
-				 itor->second = itor->second -1;
-				if ( itor->second == 0 )
-				{
-					m_ally_sizes.erase( itor );
-				}
-			}
-			itor = m_ally_sizes.find( ally );
-			if ( itor != m_ally_sizes.end() ) itor->second = itor->second + 1;
-			else m_ally_sizes[ally] = 1;
+			PlayerLeftAlly( user.BattleStatus().ally );
+			PlayerJoinedAlly( ally );
 		}
 		user.BattleStatus().ally = ally;
   }
@@ -669,58 +566,81 @@ void IBattle::ForceColour( User& user, const wxColour& col )
 
 }
 
+void IBattle::PlayerJoinedTeam( int team )
+{
+	std::map<int, int>::iterator itor = m_teams_sizes.find( team );
+	if ( itor == m_teams_sizes.end() ) m_teams_sizes[team] = 1;
+	else m_teams_sizes[team] = m_teams_sizes[team] + 1;
+}
+
+void IBattle::PlayerJoinedAlly( int ally )
+{
+	std::map<int, int>::iterator iter = m_ally_sizes.find( ally );
+	if ( iter == m_ally_sizes.end() ) m_ally_sizes[ally] = 1;
+	else m_ally_sizes[ally] = m_ally_sizes[ally] + 1;
+}
+
+void IBattle::PlayerLeftTeam( int team )
+{
+	std::map<int, int>::iterator itor = m_teams_sizes.find( team );
+	if ( itor != m_teams_sizes.end() )
+	{
+		 itor->second = itor->second -1;
+		if ( itor->second == 0 )
+		{
+			m_teams_sizes.erase( itor );
+		}
+	}
+}
+
+void IBattle::PlayerLeftAlly( int ally )
+{
+	std::map<int, int>::iterator iter = m_ally_sizes.find( ally );
+	if ( iter != m_ally_sizes.end() )
+	{
+		iter->second = iter->second - 1;
+		if ( iter->second == 0 )
+		{
+			m_ally_sizes.erase( iter );
+		}
+	}
+}
 
 void IBattle::ForceSpectator( User& user, bool spectator )
 {
 		if ( IsFounderMe() || user.BattleStatus().IsBot() )
 		{
-			 UserBattleStatus& status = user.BattleStatus();
-			 if ( status.spectator != spectator )
-			 {
-					if ( !spectator )
+			UserBattleStatus& status = user.BattleStatus();
+
+			if ( !status.spectator ) // leaving spectator status
+			{
+				PlayerJoinedTeam( status.team );
+				PlayerJoinedAlly( status.ally );
+				if ( status.ready && !status.IsBot() ) m_players_ready++;
+			}
+
+			if (spectator) // entering spectator status
+			{
+				PlayerLeftTeam( status.team );
+				PlayerLeftAlly( status.ally );
+				if ( status.ready && !status.IsBot() ) m_players_ready--;
+			}
+
+			if ( IsFounderMe() )
+			{
+				if ( status.spectator != spectator )
+				{
+					if ( spectator )
 					{
-						std::map<int, int>::iterator itor = m_teams_sizes.find( status.team );
-						if ( itor == m_teams_sizes.end() ) m_teams_sizes[status.team] = 1;
-						else m_teams_sizes[status.team] = m_teams_sizes[status.team] + 1;
-						std::map<int, int>::iterator iter = m_ally_sizes.find( status.ally );
-						if ( iter == m_ally_sizes.end() ) m_ally_sizes[status.ally] = 1;
-						else m_ally_sizes[status.ally] = m_ally_sizes[status.ally] + 1;
+							m_opts.spectators++;
 					}
 					else
 					{
-						std::map<int, int>::iterator itor = m_teams_sizes.find( status.team );
-						if ( itor != m_teams_sizes.end() )
-						{
-							 itor->second = itor->second -1;
-							if ( itor->second == 0 )
-							{
-								m_teams_sizes.erase( itor );
-							}
-						}
-						std::map<int, int>::iterator iter = m_ally_sizes.find( status.ally );
-						if ( iter != m_ally_sizes.end() )
-						{
-							iter->second = iter->second - 1;
-							if ( iter->second == 0 )
-							{
-								m_ally_sizes.erase( iter );
-							}
-						}
+							m_opts.spectators--;
 					}
-					if ( IsFounderMe() )
-					{
-						if ( spectator )
-						{
-								m_opts.spectators++;
-						}
-						else
-						{
-								m_opts.spectators--;
-						}
-						SendHostInfo( HI_Spectators );
-					}
-			 }
-
+					SendHostInfo( HI_Spectators );
+				}
+			}
 			user.BattleStatus().spectator = spectator;
 		}
 }
@@ -742,7 +662,7 @@ void IBattle::KickPlayer( User& user )
 		}
 }
 
-int IBattle::GetFreeAlly( bool excludeme )
+int IBattle::GetFreeAlly( bool excludeme ) const
 {
   int lowest = 0;
   bool changed = true;
@@ -752,7 +672,8 @@ int IBattle::GetFreeAlly( bool excludeme )
     for ( unsigned int i = 0; i < GetNumUsers(); i++ )
     {
       User& user = GetUser( i );
-      if ( ( &GetUser( i ) == &GetMe() ) && excludeme ) continue;
+      if ( ( &user == &GetMe() ) && excludeme ) continue;
+      if ( user.BattleStatus().spectator ) continue;
       if ( user.BattleStatus().ally == lowest )
       {
         lowest++;
@@ -767,7 +688,7 @@ UserPosition IBattle::GetFreePosition()
 {
 	UserPosition ret;
   UnitSyncMap map = LoadMap();
-  for ( int i = 0; i < map.info.posCount; i++ )
+  for ( int i = 0; i < int(map.info.positions.size()); i++ )
 	{
     bool taken = false;
     for ( unsigned int bi = 0; bi < GetNumUsers(); bi++ )
@@ -872,6 +793,7 @@ void IBattle::SetLocalMod( const UnitSyncMod& mod )
 {
   if ( mod.name != m_local_mod.name || mod.hash != m_local_mod.hash )
   {
+    m_previous_local_mod_name = m_local_mod.name;
     m_local_mod = mod;
     m_mod_loaded = true;
     if ( !m_host_mod.hash.IsEmpty() ) m_mod_exists = usync().ModExists( m_host_mod.name, m_host_mod.hash );
@@ -941,7 +863,7 @@ void IBattle::UnrestrictAllUnits()
 }
 
 
-std::map<wxString,int> IBattle::RestrictedUnits()
+std::map<wxString,int> IBattle::RestrictedUnits() const
 {
   return m_restricted_units;
 }
@@ -951,9 +873,13 @@ void IBattle::OnSelfLeftBattle()
     susynclib().UnSetCurrentMod(); //left battle
     m_is_self_in = false;
     ClearStartRects();
+    m_teams_sizes.clear();
+    m_ally_sizes.clear();
+    m_players_ready = 0;
+    m_players_sync = 0;
 }
 
-void IBattle::OnUnitSyncReloaded()
+void IBattle::OnUnitsyncReloaded( GlobalEvents::GlobalEventData /*data*/ )
 {
   if ( !m_host_mod.hash.IsEmpty() ) m_mod_exists = usync().ModExists( m_host_mod.name, m_host_mod.hash);
   else m_mod_exists = usync().ModExists( m_host_mod.name );
@@ -1008,7 +934,10 @@ bool IBattle::LoadOptionsPreset( const wxString& name )
         }
       }
 
-			for( unsigned int i = 0; i <= GetLastRectIdx(); ++i ) if ( GetStartRect( i ).IsOk() ) RemoveStartRect(i); // remove all rects that might come from map presets
+			for( unsigned int j = 0; j <= GetLastRectIdx(); ++j ) {
+			    if ( GetStartRect( j ).IsOk() )
+                    RemoveStartRect(j); // remove all rects that might come from map presets
+			}
 			SendHostInfo( IBattle::HI_StartRects );
 
       unsigned int rectcount = s2l( options[_T("numrects")] );
@@ -1136,13 +1065,16 @@ bool IBattle::IsFounderMe()
 bool IBattle::IsFounder( const User& user ) const
 {
     if ( UserExists( m_opts.founder ) ) {
+    	try
+    	{
         return &GetFounder() == &user;
+			}catch(...){return false;}
     }
     else
         return false;
 }
 
-int IBattle::GetMyPlayerNum()
+int IBattle::GetMyPlayerNum() const
 {
     return GetPlayerNum( GetMe() );
 }
@@ -1234,9 +1166,7 @@ void IBattle::GetBattleFromScript( bool loadmapmod )
                 status.team = player->GetInt( _T("Team") );
 								if ( !status.spectator )
 								{
-									std::map<int, int>::iterator itor = m_teams_sizes.find( status.team );
-									if ( itor == m_teams_sizes.end() ) m_teams_sizes[status.team] = 1;
-									else m_teams_sizes[status.team] = m_teams_sizes[status.team] + 1;
+									PlayerJoinedTeam( status.team );
 								}
                 status.sync = true;
                 status.ready = true;
@@ -1287,9 +1217,7 @@ void IBattle::GetBattleFromScript( bool loadmapmod )
 										status.handicap = teaminfos.Handicap;
 										if ( !status.spectator )
 										{
-											std::map<int, int>::iterator iter = m_ally_sizes.find(status.ally );
-											if ( iter == m_ally_sizes.end() ) m_ally_sizes[status.ally] = 1;
-											else m_ally_sizes[status.ally] = m_ally_sizes[status.ally] + 1;
+											PlayerJoinedAlly( status.ally );
 										}
 										if ( teaminfos.SideNum >= 0 ) status.side = teaminfos.SideNum;
 										IBattle::AllyInfoContainer allyinfos = parsed_allies[user.BattleStatus().ally];
