@@ -14,6 +14,7 @@ class iNetClass
     virtual void OnConnected( Socket* sock ) = 0;
     virtual void OnDisconnected( Socket* sock ) = 0;
     virtual void OnDataReceived( Socket* sock ) = 0;
+	virtual void Ping() = 0;
 };
 
 class FakeNetClass : public iNetClass
@@ -26,6 +27,7 @@ class FakeNetClass : public iNetClass
     void OnConnected( Socket* /*unused*/ ) {}
     void OnDisconnected( Socket* /*unused*/ ) {}
     void OnDataReceived( Socket* /*unused*/ ) {}
+	void Ping() {}
 };
 
 #endif // SPRINGLOBBY_HEADERGUARD_INETCLASS_H
