@@ -10,6 +10,7 @@
 #include "utils/controls.h"
 #include "utils/debug.h"
 #include "settings.h"
+#include "globalsmanager.h"
 #include <wx/settings.h>
 
 //(*InternalHeaders(MapSelectDialog)
@@ -48,10 +49,10 @@ BEGIN_EVENT_TABLE(MapSelectDialog,wxDialog)
 	//*)
 END_EVENT_TABLE()
 
-MapSelectDialog::MapSelectDialog(wxWindow* parent,Ui& ui)
-	: m_ui(ui)
-	, m_horizontal_direction( sett().GetHorizontalSortorder() )
-	, m_vertical_direction( sett().GetVerticalSortorder() )
+MapSelectDialog::MapSelectDialog( wxWindow* parent )
+	: WindowAttributesPickle( m_dialog_name, this, wxSize( DEFSETT_MW_WIDTH, DEFSETT_MW_HEIGHT ) ),
+	m_horizontal_direction( sett().GetHorizontalSortorder() ),
+	m_vertical_direction( sett().GetVerticalSortorder() )
 {
 	//(*Initialize(MapSelectDialog)
 	wxStaticBoxSizer* StaticBoxSizer2;
@@ -109,7 +110,7 @@ MapSelectDialog::MapSelectDialog(wxWindow* parent,Ui& ui)
 	StdDialogButtonSizer1->Realize();
 	BoxSizer2->Add(StdDialogButtonSizer1, 0, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
 	BoxSizer1->Add(BoxSizer2, 0, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
-	m_mapgrid = new MapGridCtrl(this, m_ui, wxSize(600,400), ID_MAPGRID);
+	m_mapgrid = new MapGridCtrl(this, wxSize(600,400), ID_MAPGRID);
 	BoxSizer1->Add(m_mapgrid, 1, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
 	SetSizer(BoxSizer1);
 	BoxSizer1->Fit(this);
@@ -161,11 +162,6 @@ MapSelectDialog::MapSelectDialog(wxWindow* parent,Ui& ui)
 	m_map_opts_list->InsertItem( 5, _("Max metal") );
 	m_map_opts_list->InsertItem( 6, _("Start positions") );
 
-	//could prolly go into Create() params, dunno how tho w/o meddling w wxsmith
-
-    wxPoint pos = sett().GetWindowPos( m_dialog_name , wxPoint( DEFSETT_MW_LEFT, DEFSETT_MW_TOP ) );
-    wxSize size = sett().GetWindowSize( m_dialog_name , wxSize( DEFSETT_MW_WIDTH, DEFSETT_MW_HEIGHT ) );
-    SetSize( pos.x , pos.y, size.GetWidth(), size.GetHeight() );
     Layout();
 }
 
@@ -177,14 +173,14 @@ MapSelectDialog::~MapSelectDialog()
 	sett().SetVerticalSortkeyIndex( m_vertical_choice->GetSelection() );
 	sett().SetHorizontalSortorder( m_horizontal_direction );
 	sett().SetVerticalSortorder( m_vertical_direction );
-	sett().SetWindowSize( m_dialog_name , GetSize() );
-    sett().SetWindowPos( m_dialog_name , GetPosition() );
     if ( m_filter_all->GetValue() )
         sett().SetMapSelectorFilterRadio( m_filter_all_sett );
     else if ( m_filter_recent->GetValue() )
         sett().SetMapSelectorFilterRadio( m_filter_recent_sett );
     else
         sett().SetMapSelectorFilterRadio( m_filter_popular_sett );
+	if ( IsShown() )
+		EndModal( 0 );
 }
 
 
@@ -205,7 +201,7 @@ void MapSelectDialog::OnInit( wxInitDialogEvent& /*unused*/ )
 	m_replays = usync().GetPlaybackList( true ); //true meaning replays, flase meaning savegames
 
     const unsigned int lastFilter = sett().GetMapSelectorFilterRadio();
-	m_filter_popular->Enable( m_ui.IsConnected() );
+	m_filter_popular->Enable( ui().IsConnected() );
 
 	// due to a bug / crappy design in SpringUnitSync / unitsync itself we
 	// get a replay list with one empty item when there are no replays..
@@ -216,7 +212,7 @@ void MapSelectDialog::OnInit( wxInitDialogEvent& /*unused*/ )
 	}
 
 	if ( lastFilter == m_filter_popular_sett ) {
-	    if ( m_ui.IsConnected() ) {
+	    if ( ui().IsConnected() ) {
 	        m_filter_popular->SetValue( true );
             LoadPopular();
 	    }
@@ -278,12 +274,12 @@ static MapGridCtrl::SortKey GetSelectedSortKey( wxChoice* choice )
 namespace {
 struct FilterPredicate
 {
-	FilterPredicate( const wxString& searchText ) : searchText(searchText.Lower()) {}
+	FilterPredicate( const wxString& _searchText ) : searchText(_searchText.Lower()) {}
 	bool operator () ( const UnitSyncMap& map ) const
 	{
-		return map.name.Lower().Contains( searchText )
-			|| map.info.description.Lower().Contains( searchText )
-			|| map.info.author.Lower().Contains( searchText );
+		return map.name.Lower().Find( searchText ) != wxNOT_FOUND
+			|| map.info.description.Lower().Find( searchText ) != wxNOT_FOUND
+			|| map.info.author.Lower().Find( searchText ) != wxNOT_FOUND ;
 	}
 	wxString searchText;
 };
@@ -314,7 +310,7 @@ void MapSelectDialog::OnMapSelected( wxCommandEvent& event )
 	if ( pMap == NULL) return;
 	const UnitSyncMap& map = *pMap;
 
-	m_map_name->SetLabel( RefineMapname( map.name ) + _T("\n\n") + map.info.description );
+	m_map_name->SetLabel( map.name + _T("\n\n") + map.info.description );
 
 	// TODO: refactor, this is copied from battlemaptab.cpp
 	m_map_opts_list->SetItem( 0, 1, wxString::Format( _T("%dx%d"), map.info.width/512, map.info.height/512 ) );
@@ -323,7 +319,7 @@ void MapSelectDialog::OnMapSelected( wxCommandEvent& event )
 	m_map_opts_list->SetItem( 3, 1, wxString::Format( _T("%d"), map.info.gravity ) );
 	m_map_opts_list->SetItem( 4, 1, wxString::Format( _T("%d"), map.info.extractorRadius ) );
 	m_map_opts_list->SetItem( 5, 1, wxString::Format( _T("%.3f"), map.info.maxMetal ) );
-	m_map_opts_list->SetItem( 6, 1, wxString::Format( _T("%d"), map.info.posCount ) );
+	m_map_opts_list->SetItem( 6, 1, wxString::Format( _T("%d"), map.info.positions.size() ) );
 }
 
 void MapSelectDialog::OnMapLoadingCompleted( wxCommandEvent& /*unused*/ )
@@ -379,13 +375,13 @@ void MapSelectDialog::LoadPopular()
 	m_mapgrid->Clear();
 
 	try {
-		m_ui.GetServer().battles_iter->IteratorBegin();
-		while ( !m_ui.GetServer().battles_iter->EOL() ) {
-			Battle* b = m_ui.GetServer().battles_iter->GetBattle();
+		ui().GetServer().battles_iter->IteratorBegin();
+		while ( !ui().GetServer().battles_iter->EOL() ) {
+			Battle* b = ui().GetServer().battles_iter->GetBattle();
 			if ( b != NULL ) m_mapgrid->AddMap( b->GetHostMapName() );
 		}
 	}
-	catch (...) {} // m_ui.GetServer may throw when disconnected...
+	catch (...) {} // ui().GetServer may throw when disconnected...
 
 	m_mapgrid->Refresh();
 }
@@ -402,9 +398,9 @@ void MapSelectDialog::LoadRecent()
 	for ( int i = 0; i < count; ++i ) {
 		// prefix and suffix with underscore to prevent most common partial matches
 		const wxString mapname = _T("_") + m_maps[i].BeforeLast( '.' ) + _T("_");
-		unsigned int replaycount = m_replays.GetCount();
+		long replaycount = long(m_replays.GetCount());
 		for ( int replaynum = 0; replaynum < replaycount; replaynum++ ) {
-			if ( m_replays[replaynum].Contains( mapname ) )
+			if ( m_replays[replaynum].Find( mapname ) != wxNOT_FOUND )
 				m_mapgrid->AddMap( m_maps[i] );
 		}
 	}
@@ -437,3 +433,24 @@ void MapSelectDialog::OnFilterTextChanged(wxCommandEvent& /*unused*/)
 	wxLogDebugFunc( _T("") );
 	UpdateSortAndFilter();
 }
+#ifdef __WXMSW__
+	#include "ui.h"
+	#include "mainwindow.h"
+#endif
+MapSelectDialog& mapSelectDialog()
+{
+	#ifdef __WXMSW__
+		static MapSelectDialog* m = new MapSelectDialog( &ui().mw() );
+		return *m;
+	#else
+	/* either a globals handled or directly on stack created dialog would result in sigsegv / sigabrt in dtor, no idea why */
+		static MapSelectDialog* m = new MapSelectDialog( 0 );
+		return *m;
+	#endif
+}
+
+void MapSelectDialog::OnUnitsyncReloaded( GlobalEvents::GlobalEventData /*data*/ )
+{
+	wxInitDialogEvent dummy;
+	AddPendingEvent( dummy );
+}
