@@ -6,8 +6,10 @@
 class wxCheckBox;
 class wxComboBox;
 class wxCommandEvent;
-class Battle;
-class wxSpinCtrlDbl;
+class IBattle;
+template <class P>
+class SlSpinCtrlDouble;
+class SlSpinDoubleEvent;
 class wxTextCtrl;
 class wxStaticText;
 class wxButton;
@@ -16,23 +18,24 @@ class SingleOptionDialog: public wxDialog
 {
 
 	public:
-			SingleOptionDialog( Battle& battle, const wxString& optiontag );
+			SingleOptionDialog( IBattle& battle, const wxString& optiontag );
 
 			void OnOk(wxCommandEvent& event);
 			void OnCancel(wxCommandEvent& event);
 
+			//! dummy event receiver, mandated by the control implementation
+			void OnSpinCtrlDoubleChange(SlSpinDoubleEvent& /*event*/){}
+
 	protected:
-			Battle& m_battle;
+			IBattle& m_battle;
 			wxString m_tag;
 
 			wxCheckBox* m_checkbox;
 			wxComboBox* m_combobox;
-			wxSpinCtrlDbl* m_spinctrl;
+			SlSpinCtrlDouble<SingleOptionDialog>* m_spinctrl;
 			wxTextCtrl* m_textctrl;
 			wxButton* m_cancel_button;
 			wxButton* m_ok_button;
-
-			DECLARE_EVENT_TABLE();
 };
 
 enum
