@@ -14,7 +14,8 @@ struct Replay
     wxString ModName;
     wxString SpringVersion;
     wxString Filename;
-    wxString date;
+    time_t date;
+    wxString date_string;
     OfflineBattle battle;
     Replay():id(0),playernum(0),can_watch(false),duration(0),size(0){};
 
@@ -27,12 +28,13 @@ struct Savegame
     int playernum;
     bool can_watch;
     int duration; //in seconds
-    int size; //in bytes
+	unsigned long size; //in bytes
     wxString MapName;
     wxString ModName;
     wxString SpringVersion;
     wxString Filename;
-    wxString date;
+    time_t date;
+    wxString date_string;
     OfflineBattle battle;
     Savegame():id(0),playernum(0),can_watch(false),duration(0),size(0){};
 
