@@ -19,11 +19,15 @@
 #include "channel/channel.h"
 #include "user.h"
 #include "utils/debug.h"
+#include "uiutils.h"
 #include "server.h"
 #include "battle.h"
 #include "httpdownloader.h"
 #include "settings.h"
-#include "settings++/custom_dialogs.h"
+#include "utils/customdialogs.h"
+#include "utils/tasutil.h"
+#include "utils/uievents.h"
+
 #ifndef NO_TORRENT_SYSTEM
 #include "torrentwrapper.h"
 #endif
@@ -48,20 +52,17 @@ void ServerEvents::OnDisconnected( bool wasonline )
     wxLogDebugFunc( _T("") );
     m_serv.SetRequiredSpring (_T(""));
     ui().OnDisconnected( m_serv, wasonline );
-#ifndef NO_TORRENT_SYSTEM
-    try // settings may be already destroyed
-    {
-        if ( sett().GetTorrentSystemAutoStartMode() == 0 ) torrent().DisconnectFromP2PSystem();
-    }
-    catch (GlobalDestroyedError e)
-    {
-    }
-#endif
 }
 
 
 void ServerEvents::OnLogin()
 {
+}
+
+
+void ServerEvents::OnLoginInfoComplete()
+{
+    wxLogDebugFunc( _T("") );
 	wxString nick = m_serv.GetMe().GetNick();
 	wxArrayString highlights = sett().GetHighlightedWords();
 	if ( highlights.Index( nick ) == -1 )
@@ -69,21 +70,12 @@ void ServerEvents::OnLogin()
 		highlights.Add( nick );
 		sett().SetHighlightedWords( highlights );
 	}
-}
-
-
-void ServerEvents::OnLoginInfoComplete()
-{
-    wxLogDebugFunc( _T("") );
     //m_serv.RequestChannels();
     std::vector<ChannelJoinInfo> autojoin = sett().GetChannelsJoin();
     for ( std::vector<ChannelJoinInfo>::iterator itor = autojoin.begin(); itor != autojoin.end(); itor++ )
     {
         m_serv.JoinChannel( itor->name, itor->password );
     }
-#ifndef NO_TORRENT_SYSTEM
-    if ( sett().GetTorrentSystemAutoStartMode() == 0 ) torrent().ConnectToP2PSystem();
-#endif
     ui().OnLoggedIn( );
 }
 
@@ -122,8 +114,9 @@ void ServerEvents::OnMotd( const wxString& msg )
 
 void ServerEvents::OnPong( wxLongLong ping_time )
 {
-    //wxLongLong is non-POD and cannot be passed to wxFormat as such. use c-string rep instead. converting to long might loose precision
-    ui().OnServerMessage( m_serv, wxString::Format( _("ping reply took %s ms"), ping_time.ToString().c_str() ) );
+	//wxLongLong is non-POD and cannot be passed to wxFormat as such. use c-string rep instead. converting to long might loose precision
+	UiEvents::StatusData data( wxString::Format( _("ping: %s ms"), ping_time.ToString().c_str() ), 2 );
+	UiEvents::GetStatusEventSender( UiEvents::addStatusMessage ).SendEvent( data );
 }
 
 
@@ -173,6 +166,8 @@ void ServerEvents::OnUserStatus( const wxString& nick, UserStatus status )
         if ( user.GetBattle() != 0 )
         {
             Battle& battle = *user.GetBattle();
+            try
+            {
             if ( battle.GetFounder().GetNick() == user.GetNick() )
             {
                 if ( status.in_game != battle.GetInGame() )
@@ -182,6 +177,7 @@ void ServerEvents::OnUserStatus( const wxString& nick, UserStatus status )
                     else ui().OnBattleInfoUpdated( battle );
                 }
             }
+            }catch(...){}
         }
     }
     catch (...)
@@ -201,16 +197,19 @@ void ServerEvents::OnUserQuit( const wxString& nick )
 				if ( userbattle )
 				{
 					int battleid = userbattle->GetID();
-					if ( &userbattle->GetFounder() == &user )
+					try
 					{
-						for ( int i = 0; i < userbattle->GetNumUsers(); i ++ )
+						if ( &userbattle->GetFounder() == &user )
 						{
-							User& battleuser = userbattle->GetUser( i );
-							OnUserLeftBattle( battleid, battleuser.GetNick() );
+							for ( int i = 0; i < int(userbattle->GetNumUsers()); i ++ )
+							{
+								User& battleuser = userbattle->GetUser( i );
+								OnUserLeftBattle( battleid, battleuser.GetNick() );
+							}
+							 OnBattleClosed( battleid );
 						}
-						 OnBattleClosed( battleid );
-					}
-					else OnUserLeftBattle( battleid, user.GetNick() );
+						else OnUserLeftBattle( battleid, user.GetNick() );
+					}catch(...){}
 				}
         ui().OnUserOffline( user );
         m_serv._RemoveUser( nick );
@@ -362,15 +361,17 @@ void ServerEvents::OnUserJoinedBattle( int battleid, const wxString& nick )
 
         battle.OnUserAdded( user );
         ui().OnUserJoinedBattle( battle, user );
-
-        if ( &user == &battle.GetFounder() )
-        {
-            if ( user.Status().in_game )
-            {
-                battle.SetInGame( true );
-                battle.StartSpring();
-            }
-        }
+				try
+				{
+					if ( &user == &battle.GetFounder() )
+					{
+							if ( user.Status().in_game )
+							{
+									battle.SetInGame( true );
+									battle.StartSpring();
+							}
+					}
+        }catch(...){}
     }
     catch (std::runtime_error &except)
     {
@@ -384,9 +385,9 @@ void ServerEvents::OnUserLeftBattle( int battleid, const wxString& nick )
     try
     {
         Battle& battle = m_serv.GetBattle( battleid );
-				User& user = battle.GetUser( nick );
+        User& user = battle.GetUser( nick );
         battle.OnUserRemoved( user );
-				ui().OnUserLeftBattle( battle, user );
+        ui().OnUserLeftBattle( battle, user );
     }
     catch (std::runtime_error &except)
     {
@@ -427,7 +428,7 @@ void ServerEvents::OnSetBattleInfo( int battleid, const wxString& param, const w
     try
     {
         Battle& battle = m_serv.GetBattle( battleid );
-
+		battle.m_script_tags[param] = value;
         wxString key = param;
         if ( key.Left( 5 ) == _T("game/") )
         {
@@ -448,10 +449,10 @@ void ServerEvents::OnSetBattleInfo( int battleid, const wxString& param, const w
             {
             	OnBattleDisableUnit( battleid, key.AfterFirst(_T('/')), s2l(value) );
             }
-            else if ( key.Left( 4 ) == _T( "team" ) && key.Contains( _T("startpos") ) )
+            else if ( key.Left( 4 ) == _T( "team" ) && key.Find( _T("startpos") ) != wxNOT_FOUND )
             {
             	 int team = s2l( key.BeforeFirst(_T('/')).Mid( 4 ) );
-							 if ( key.Contains( _T("startposx") ) )
+							 if ( key.Find( _T("startposx") ) != wxNOT_FOUND )
 							 {
 							 	 int numusers = battle.GetNumUsers();
 							 	 for ( int i = 0; i < numusers; i++ )
@@ -465,7 +466,7 @@ void ServerEvents::OnSetBattleInfo( int battleid, const wxString& param, const w
 							 	 	 }
 							 	 }
 							 }
-							 else if ( key.Contains( _T("startposy") ) )
+							 else if ( key.Find( _T("startposy") ) != wxNOT_FOUND )
 							 {
 							 	 int numusers = battle.GetNumUsers();
 							 	 for ( int i = 0; i < numusers; i++ )
@@ -890,10 +891,13 @@ void ServerEvents::OnMutelistBegin( const wxString& channel )
 void ServerEvents::OnMutelistItem( const wxString& /*unused*/, const wxString& mutee, const wxString& description )
 {
     wxString message = mutee;
-    if ( description == _T("indefinite") )
-        message << _(" indefinite time remaining");
-    else
-        message << wxString::Format( _(" %d minutes remaining") , s2l(description)/60 + 1 ) ;
+    wxString desc = description;
+    wxString mutetime = GetWordParam( desc );
+		long time;
+		if ( mutetime == _T("indefinite") ) message << _(" indefinite time remaining");
+		else if ( mutetime.ToLong(&time) ) message << wxString::Format( _(" %d minutes remaining"), time/60 + 1 );
+		else message << mutetime;
+		if ( !desc.IsEmpty() )  message << _T(", ") << desc;
     mutelistWindow( message );
 }
 
@@ -930,10 +934,10 @@ void ServerEvents::OnScriptEnd( int battleid )
 }
 
 
-void ServerEvents::OnFileDownload( bool autolaunch, bool autoclose, bool disconnectonrefuse, const wxString& FileName, const wxString& url, const wxString& description )
+void ServerEvents::OnFileDownload( bool autolaunch, bool autoclose, bool /*disconnectonrefuse*/, const wxString& FileName, const wxString& url, const wxString& description )
 {
 	wxString refinedurl;
-	if ( url.Contains(_T("http://")) ) refinedurl = url.AfterFirst(_T('/')).AfterFirst(_T('/'));
+	if ( url.Find(_T("http://")) != wxNOT_FOUND ) refinedurl = url.AfterFirst(_T('/')).AfterFirst(_T('/'));
 	else refinedurl = url;
 	bool result = ui().Ask( _("Download update"), wxString::Format( _("Would you like to download %s ? The file offers the following updates:\n\n%s\n\nThe download will be started in the background, you will be notified on operation completed."), url.c_str(), description.c_str() ) );
 	if ( result )
@@ -945,7 +949,7 @@ void ServerEvents::OnFileDownload( bool autolaunch, bool autoclose, bool disconn
 		else filename = _T("Spring installer.exe");
 		m_savepath = sett().GetCurrentUsedDataDir() + filename;
 		wxLogMessage(_T("downloading update in: %s, from: %s"),m_savepath.c_str(),refinedurl.c_str());
-		ui().OpenWebBrowser( url );
+		OpenWebBrowser( url );
 		//new HttpDownloaderThread<ServerEvents>( refinedurl, m_savepath, *this, wxID_HIGHEST + 100, true, false );
 	}
 }
