@@ -1,18 +1,10 @@
 #include "helpmenufunctions.h"
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif //HAVE_CONFIG_H
-
-#ifndef VERSION 
-	#define VERSION "unknown"
-#endif //VERSION 
-
-
 #include <wx/icon.h>
 #include "../images/springsettings.xpm"
 
-#include "custom_dialogs.h"
+#include "../utils/customdialogs.h"
+#include "../updater/updatehelper.h"
 #include <wx/intl.h>
 #include "se_utils.h"
 #include <string>
@@ -21,10 +13,17 @@
 
 void showAbout()
 {
-    std::string ver = std::string("0.2.1 revision ") + VERSION;
     wxAboutDialogInfo info;
-    info.SetName(_T("SpringSettings"));
-    info.SetVersion(_T("0.2.1"));//WX_STRING(ver));
+	if ( IsSettingsStandAlone() )
+	{
+		info.SetName(_T("SpringSettings"));
+		info.SetVersion(_T("0.2.1"));
+	}
+	else
+	{
+		info.SetName(_T("SpringLobby"));
+		info.SetVersion(GetSpringLobbyVersion());
+	}
     info.SetDescription(_("SpringSettings is a graphical frontend to the Settings of the Spring engine"));
     info.SetCopyright(_T("(C) 2007-2008 koshi <koshi@springlobby.info>"));
     info.SetIcon(wxIcon(springsettings_xpm));
