@@ -5,10 +5,11 @@
 #include <vector>
 
 const int CACHE_VERSION     = 10;
-const int SETTINGS_VERSION  = 15;
+const int SETTINGS_VERSION  = 21;
 
 const wxString DEFSETT_DEFAULT_SERVER_NAME= _T("Official server");
 const wxString DEFSETT_DEFAULT_SERVER_HOST = _T("taspringmaster.clan-sy.com");
+const wxString BattlePostfix = _T("_battle");
 const int DEFSETT_DEFAULT_SERVER_PORT = 8200;
 const bool DEFSETT_SAVE_PASSWORD = false;
 const unsigned int DEFSETT_MW_WIDTH = 880;
@@ -17,8 +18,8 @@ const unsigned int DEFSETT_MW_TOP = 50;
 const unsigned int DEFSETT_MW_LEFT = 50;
 const unsigned int DEFSETT_SPRING_PORT = 8452;
 
-const unsigned int SET_MODE_EXPERT = 5000;
-const unsigned int SET_MODE_SIMPLE = 5001;
+const int SET_MODE_EXPERT = 5000;
+const int SET_MODE_SIMPLE = 5001;
 const unsigned int DEFSETT_SW_WIDTH = 770;
 const unsigned int DEFSETT_SW_HEIGHT = 580;
 const unsigned int DEFSETT_SW_TOP = 50;
@@ -32,6 +33,7 @@ const unsigned int SPRING_MAX_ALLIES = 16;
  */
 const bool DEFSETT_WEB_BROWSER_USE_DEFAULT = true;
 
+#include <wx/config.h>
 #include <wx/fileconf.h>
 #include "useractions.h"
 #include "Helper/sortutil.h"
@@ -59,6 +61,17 @@ struct ChannelJoinInfo
 	wxString password;
 };
 
+//!convenience class for saving and displaying a choice of discrete screen pos
+class ScreenPosition : public wxArrayString
+{
+public:
+	ScreenPosition(){ Add(_("Bottom right"));Add(_("Bottom left"));Add(_("Top right"));Add(_("Top left"));}
+	static const size_t bottom_right	= 0;
+	static const size_t bottom_left		= 1;
+	static const size_t top_right		= 2;
+	static const size_t top_left		= 3;
+};
+
 class SL_WinConf : public wxFileConfig
 {
     public:
@@ -83,16 +96,15 @@ class Settings
     Settings();
     ~Settings();
 
-    /** used for passing config file at command line
-    */
+    //! used for passing config file at command line
     static bool m_user_defined_config;
     static wxString m_user_defined_config_path;
 
-		/// used to import default configs from a file in windows
-		#ifdef __WXMSW__
-    void SetDefaultConfigs( SL_WinConf& conf );
+    /// used to import default configs from a file in windows
+    #ifdef __WXMSW__
+        void SetDefaultConfigs( SL_WinConf& conf );
     #else
-    void SetDefaultConfigs( wxConfig& conf );
+        void SetDefaultConfigs( wxConfig& conf );
     #endif
 
     /// list all entries subkeys of a parent group
@@ -100,7 +112,7 @@ class Settings
     /// list all groups subkeys of a parent group
     wxArrayString GetEntryList( const wxString& base_key );
     /// counts all groups subkeys of a parent group
-		unsigned int GetGroupCount( const wxString& base_key );
+    unsigned int GetGroupCount( const wxString& base_key );
 
     bool IsPortableMode();
     void SetPortableMode( bool mode );
@@ -310,9 +322,12 @@ class Settings
     wxSize  GetWindowSize( const wxString& window, const wxSize& def );
     void    SetWindowSize( const wxString& window, const wxSize& size  );
 
-    wxPoint  GetWindowPos( const wxString& window, const wxPoint& def );
+	wxPoint GetWindowPos( const wxString& window, const wxPoint& def );
     void    SetWindowPos( const wxString& window, const wxPoint& pos );
 
+	bool	GetWindowMaximized( const wxString& window );
+	void	GetWindowMaximized( const wxString& window, bool maximized );
+
     bool UseOldSpringLaunchMethod();
     void SetOldSpringLaunchMethod( bool value );
 
@@ -327,6 +342,7 @@ class Settings
 
     void SetColumnWidth( const wxString& list_name, const int column_ind, const int column_width );
     int GetColumnWidth( const wxString& list_name, const int column );
+	void NukeColumnWidths();
     //! used to signal unset column width in Get...
     static const int columnWidthUnset = -3;
     static const int columnWidthMinimum = 5;
@@ -345,8 +361,18 @@ class Settings
 
     void TranslateSavedColumWidths();
 
-    wxString GetEditorPath( );
+	wxString GetEditorPath();
     void SetEditorPath( const wxString& path );
+
+    void SetAutoloadedChatlogLinesCount( const int count );
+	int GetAutoloadedChatlogLinesCount();
+
+	void SetUseNotificationPopups( const bool use );
+	bool GetUseNotificationPopups();
+	void SetNotificationPopupPosition( const size_t index );
+	size_t GetNotificationPopupPosition();
+	void SetNotificationPopupDisplayTime( const unsigned int seconds );
+	unsigned int GetNotificationPopupDisplayTime( );
     /*@}*/
 
     /* ================================================================ */
@@ -617,14 +643,12 @@ class Settings
     int GetTorrentThrottledDownloadRate();
     void SetTorrentThrottledDownloadRate( int speed );
 
-    int GetTorrentSystemAutoStartMode();
-    void SetTorrentSystemAutoStartMode( int mode );
-
     void SetTorrentMaxConnections( int connections );
     int GetTorrentMaxConnections();
 
-    void SetTorrentListToResume( const wxArrayString& list );
-    wxArrayString GetTorrentListToResume();
+	void SetTorrentListToResume( const std::vector<wxString>& list );
+	std::vector<wxString> GetTorrentListToResume();
+	void ClearTorrentListToResume();
 
     /** Get the path to the directory where *.torrent files are stored.
      */
@@ -649,9 +673,20 @@ class Settings
      */
     void SaveLayout( wxString& layout_name, wxString& layout_string );
     wxString GetLayout( wxString& layout_name );
-    wxArrayString GetLayoutList();
-    void SetDefaultLayout( const wxString& layout_name );
-    wxString GetDefaultLayout();
+
+    void SavePerspective( const wxString& notebook_name, const wxString& perspective_name, const wxString& layout_string );
+    wxString LoadPerspective( const wxString& notebook_name, const wxString& perspective_name );
+    wxString GetLastPerspectiveName( );
+    void SetLastPerspectiveName( const wxString&  name );
+    void SetAutosavePerspective( bool autosave );
+    bool GetAutosavePerspective( );
+    wxArrayString GetPerspectives();
+    bool PerspectiveExists( const wxString& perspective_name );
+	bool DoResetPerspectives();
+	void SetDoResetPerspectives( bool do_it );
+
+    void RemoveLayouts();
+
     //! icons for mainwindow tabs??
     bool GetUseTabIcons();
     void SetUseTabIcons( bool use );
