@@ -24,13 +24,14 @@
 
 #include "settings.h"
 #include "springunitsynclib.h"
-#include "settings++/custom_dialogs.h"
-#include "unitsyncthread.h"
+#include "utils/customdialogs.h"
 #include "globalsmanager.h"
 #include "uiutils.h"
 #include "utils/debug.h"
 #include "utils/conversion.h"
 #include "utils/misc.h"
+#include "utils/globalevents.h"
+#include "utils/uievents.h"
 
 
 #define LOCK_UNITSYNC wxCriticalSectionLocker lock_criticalsection(m_lock)
@@ -40,8 +41,9 @@ const wxEventType UnitSyncAsyncOperationCompletedEvt = wxNewEventType();
 
 IUnitSync& usync()
 {
-  static GlobalObjectHolder<SpringUnitSync> m_sync;
-  return m_sync;
+    static LineInfo<SpringUnitSync> m( AT );
+    static GlobalObjectHolder<SpringUnitSync, LineInfo<SpringUnitSync> > m_sync( m );
+    return m_sync;
 }
 
 
@@ -66,12 +68,14 @@ SpringUnitSync::~SpringUnitSync()
 bool SpringUnitSync::LoadUnitSyncLib( const wxString& unitsyncloc )
 {
    LOCK_UNITSYNC;
+   UiEvents::ScopedStatusMessage staus(_("loading unitsync"), 0);
    wxLogDebugFunc( _T("") );
    bool ret = _LoadUnitSyncLib( unitsyncloc );
    if (ret)
    {
       m_cache_path = sett().GetCachePath();
       PopulateArchiveList();
+      GetGlobalEventSender(GlobalEvents::OnUnitsyncReloaded).SendEvent( 0 );
    }
    return ret;
 }
@@ -124,8 +128,8 @@ void SpringUnitSync::PopulateArchiveList()
 		 int count = susynclib().GetPrimaryModArchiveCount( i );
 		 if ( count > 0 )
 		 {
-		   archivename = susynclib().GetPrimaryModArchive( 0 );
-			 unchainedhash = susynclib().GetArchiveChecksum( archivename );
+			archivename = susynclib().GetPrimaryModArchive( i );
+			unchainedhash = susynclib().GetArchiveChecksum( archivename );
 		 }
     } catch (...) { continue; }
     try
@@ -327,6 +331,7 @@ UnitSyncMap SpringUnitSync::GetMapEx( int index )
   if ( index < 0 ) return m;
 
   m.name = m_map_array[index];
+
   m.hash = m_maps_list[m.name];
 
   m.info = _GetMapInfoEx( m.name );
@@ -464,6 +469,30 @@ GameOptions SpringUnitSync::GetModOptions( const wxString& name )
   return ret;
 }
 
+GameOptions SpringUnitSync::GetModCustomizations( const wxString& modname )
+{
+    wxLogDebugFunc( modname );
+
+    GameOptions ret;
+    int count = susynclib().GetCustomOptionCount( modname, _T("LobbyOptions.lua") );
+    for (int i = 0; i < count; ++i) {
+        GetOptionEntry( i, ret );
+    }
+    return ret;
+}
+
+GameOptions SpringUnitSync::GetSkirmishOptions( const wxString& modname, const wxString& skirmish_name )
+{
+    wxLogDebugFunc( modname );
+
+    GameOptions ret;
+    int count = susynclib().GetCustomOptionCount( modname, skirmish_name );
+    for (int i = 0; i < count; ++i) {
+        GetOptionEntry( i, ret );
+    }
+    return ret;
+}
+
 wxArrayString SpringUnitSync::GetModDeps( const wxString& modname )
 {
 	wxArrayString ret;
@@ -494,22 +523,30 @@ wxImage SpringUnitSync::GetSidePicture( const wxString& modname, const wxString&
 {
   wxLogDebugFunc( _T("") );
 
-  wxImage cache;
-
-	susynclib().SetCurrentMod( modname );
 	wxLogDebugFunc( _T("SideName = \"") + SideName + _T("\"") );
 	wxString ImgName = _T("SidePics");
 	ImgName += _T("/");
 	ImgName += SideName.Upper();
 	ImgName += _T(".bmp");
 
-	int ini = susynclib().OpenFileVFS (ImgName );
+    return GetImage( modname, ImgName );
+}
+
+wxImage SpringUnitSync::GetImage( const wxString& modname, const wxString& image_path )
+{
+  wxLogDebugFunc( _T("") );
+
+    wxImage cache;
+
+	susynclib().SetCurrentMod( modname );
+
+	int ini = susynclib().OpenFileVFS ( image_path );
 	ASSERT_EXCEPTION( ini, _T("cannot find side image") );
 
 	int FileSize = susynclib().FileSizeVFS(ini);
 	if (FileSize == 0) {
 		susynclib().CloseFileVFS(ini);
-		ASSERT_EXCEPTION( FileSize, _T("side image has size 0") );
+		ASSERT_EXCEPTION( FileSize, _T("image has size 0") );
 	}
 
 	uninitialized_array<char> FileContent(FileSize);
@@ -520,8 +557,9 @@ wxImage SpringUnitSync::GetSidePicture( const wxString& modname, const wxString&
 	cache.InitAlpha();
 	for ( int x = 0; x < cache.GetWidth(); x++ )
 		for ( int y = 0; y < cache.GetHeight(); y++ )
-			if ( cache.GetBlue( x, y ) == 255 && cache.GetGreen( x, y ) == 255 && cache.GetRed( x, y ) == 255 ) cache.SetAlpha( x, y, 0 ); // set pixel to be transparent
-  return cache;
+			if ( cache.GetBlue( x, y ) == 255 && cache.GetGreen( x, y ) == 255 && cache.GetRed( x, y ) == 255 )
+                cache.SetAlpha( x, y, 0 ); // set pixel to be transparent
+    return cache;
 }
 
 
@@ -549,13 +587,13 @@ wxArrayString SpringUnitSync::GetAIList( const wxString& modname )
 	{
 		// list dynamic link libraries
 		wxArrayString dlllist = susynclib().FindFilesVFS( wxDynamicLibrary::CanonicalizeName(_T("AI/Bot-libs/*"), wxDL_MODULE) );
-		for( int i = 0; i < dlllist.GetCount(); i++ )
+		for( int i = 0; i < long(dlllist.GetCount()); i++ )
 		{
 			if ( ret.Index( dlllist[i].BeforeLast( '/') ) == wxNOT_FOUND ) ret.Add ( dlllist[i] ); // don't add duplicates
 		}
 		// list jar files (java AIs)
 		wxArrayString jarlist = susynclib().FindFilesVFS( _T("AI/Bot-libs/*.jar") );
-		for( int i = 0; i < jarlist.GetCount(); i++ )
+		for( int i = 0; i < long(jarlist.GetCount()); i++ )
 		{
 			if ( ret.Index( jarlist[i].BeforeLast( '/') ) == wxNOT_FOUND ) ret.Add ( jarlist[i] ); // don't add duplicates
 		}
@@ -770,7 +808,7 @@ MapInfo SpringUnitSync::_GetMapInfoEx( const wxString& mapname )
       {
         cache = GetCacheFile( GetFileCachePath( mapname, m_maps_unchained_hash[mapname], false ) + _T(".infoex") );
 
-        ASSERT_EXCEPTION( cache.GetCount() >= 11, _T("not enough lines found in cache info ex") );
+		ASSERT_EXCEPTION( cache.GetCount() >= 11, _T("not enough lines found in cache info ex") );
         info.author = cache[0];
         info.tidalStrength =  s2l( cache[1] );
         info.gravity = s2l( cache[2] );
@@ -780,19 +818,25 @@ MapInfo SpringUnitSync::_GetMapInfoEx( const wxString& mapname )
         info.maxWind = s2l( cache[6] );
         info.width = s2l( cache[7] );
         info.height = s2l( cache[8] );
-        info.posCount = s2l( cache[9] );
-
-        wxArrayString posinfo = wxStringTokenize( cache[10], _T(' '), wxTOKEN_RET_EMPTY );
-        for ( int i = 0; i < info.posCount; i++)
+		#ifndef __WXMSW__
+		wxArrayString posinfo = wxStringTokenize( cache[10], _T(' '), wxTOKEN_RET_EMPTY );
+		#else
+		wxArrayString posinfo = wxStringTokenize( cache[9], _T(' '), wxTOKEN_RET_EMPTY );
+		#endif
+		for ( unsigned int i = 0; i < posinfo.GetCount(); i++)
         {
            StartPos position;
            position.x = s2l( posinfo[i].BeforeFirst( _T('-') ) );
            position.y = s2l( posinfo[i].AfterFirst( _T('-') ) );
-           info.positions[i] = position;
+           info.positions.push_back( position );
         }
 
         unsigned int LineCount = cache.GetCount();
+		#ifndef __WXMSW__
         for ( unsigned int i = 11; i < LineCount; i++ ) info.description << cache[i] << _T('\n');
+		#else
+		for ( unsigned int i = 10; i < LineCount; i++ ) info.description << cache[i] << _T('\n');
+		#endif
 
       }
       catch (...)
@@ -808,10 +852,9 @@ MapInfo SpringUnitSync::_GetMapInfoEx( const wxString& mapname )
         cache.Add( TowxString( info.maxWind )  );
         cache.Add( TowxString( info.width ) );
         cache.Add( TowxString( info.height ) );
-        cache.Add( TowxString( info.posCount ) );
 
         wxString postring;
-        for ( int i = 0; i < info.posCount; i++)
+		for ( unsigned int i = 0; i < info.positions.size(); i++)
         {
            postring << TowxString( info.positions[i].x ) << _T('-') << TowxString( info.positions[i].y ) << _T(' ');
         }
@@ -825,7 +868,6 @@ MapInfo SpringUnitSync::_GetMapInfoEx( const wxString& mapname )
       }
   }
   catch ( ... ) {
-      info.posCount = 0;
       info.width = 1;
       info.height = 1;
   }
@@ -835,6 +877,21 @@ MapInfo SpringUnitSync::_GetMapInfoEx( const wxString& mapname )
   return info;
 }
 
+void SpringUnitSync::OnReload( wxCommandEvent& /*event*/ )
+{
+	ReloadUnitSyncLib();
+}
+
+void SpringUnitSync::AddReloadEvent(  )
+{
+	wxCommandEvent evt( wxUnitsyncReloadEvent, wxNewId() );
+	AddPendingEvent( evt );
+}
+
+wxArrayString SpringUnitSync::FindFilesVFS( const wxString& pattern )
+{
+	return susynclib().FindFilesVFS( pattern );
+}
 
 bool SpringUnitSync::ReloadUnitSyncLib()
 {
@@ -926,14 +983,15 @@ wxString SpringUnitSync::GetArchivePath( const wxString& name )
 
 wxArrayString SpringUnitSync::GetScreenshotFilenames()
 {
-    wxSortedArrayString ret;
+    wxArrayString ret;
     if ( !IsLoaded() ) return ret;
 
     ret = susynclib().FindFilesVFS( _T("screenshots/*.*") );
-    for ( int i = 0; i < ret.Count() - 1; ++i ) {
+    for ( int i = 0; i < long(ret.Count() - 1); ++i ) {
             if ( ret[i] == ret[i+1] )
                 ret.RemoveAt( i+1 );
     }
+    ret.Sort();
     return ret;
 }
 
@@ -1095,9 +1153,9 @@ void SpringUnitSync::PrefetchMap( const wxString& mapname )
   // 50% hits without, 80% hits with this code.  (cache size 20 images)
 
   const int length = std::max(0, int(mapname.length()) - 4);
-  const int hash = (mapname[length * 1/4] << 16)
-                 | (mapname[length * 2/4] << 8)
-                 | (mapname[length * 3/4]);
+  const int hash = ( wxChar(mapname[length * 1/4]) << 16 )
+                 | ( wxChar(mapname[length * 2/4]) << 8  )
+                 | wxChar(mapname[length * 3/4]);
   const int priority = -hash;
 
   {
@@ -1162,7 +1220,7 @@ void SpringUnitSync::GetMetalmapAsync( const wxString& mapname, int evtHandlerId
   _GetMapImageAsync( mapname, &SpringUnitSync::GetMetalmap, evtHandlerId );
 }
 
-void SpringUnitSync::GetMetalmapAsync( const wxString& mapname, int width, int height, int evtHandlerId )
+void SpringUnitSync::GetMetalmapAsync( const wxString& mapname, int /*width*/, int /*height*/, int evtHandlerId )
 {
   GetMetalmapAsync( mapname, evtHandlerId );
 }
@@ -1173,7 +1231,7 @@ void SpringUnitSync::GetHeightmapAsync( const wxString& mapname, int evtHandlerI
   _GetMapImageAsync( mapname, &SpringUnitSync::GetHeightmap, evtHandlerId );
 }
 
-void SpringUnitSync::GetHeightmapAsync( const wxString& mapname, int width, int height, int evtHandlerId )
+void SpringUnitSync::GetHeightmapAsync( const wxString& mapname, int /*width*/, int /*height*/, int evtHandlerId )
 {
   GetHeightmapAsync( mapname, evtHandlerId );
 }
