@@ -40,7 +40,8 @@ SpringUnitSyncLib::~SpringUnitSyncLib()
 
 SpringUnitSyncLib& susynclib()
 {
-  static GlobalObjectHolder<SpringUnitSyncLib> lib;
+    static LineInfo<SpringUnitSyncLib> m( AT );
+  static GlobalObjectHolder<SpringUnitSyncLib, LineInfo<SpringUnitSyncLib> > lib( m );
   return lib.GetInstance();
 }
 
@@ -173,6 +174,7 @@ void SpringUnitSyncLib::_Load( const wxString& path )
     m_get_luaai_desc = (GetLuaAIDescPtr)_GetLibFuncPtr(_T("GetLuaAIDesc"));
 
     m_get_map_option_count = (GetMapOptionCountPtr)_GetLibFuncPtr(_T("GetMapOptionCount"));
+    m_get_custom_option_count = (GetCustomOptionCountPtr)_GetLibFuncPtr(_T("GetCustomOptionCount"));
     m_get_mod_option_count = (GetModOptionCountPtr)_GetLibFuncPtr(_T("GetModOptionCount"));
     m_get_skirmish_ai_option_count = (GetSkirmishAIOptionCountPtr)_GetLibFuncPtr(_T("GetSkirmishAIOptionCount"));
     m_get_option_key = (GetOptionKeyPtr)_GetLibFuncPtr(_T("GetOptionKey"));
@@ -426,8 +428,7 @@ void SpringUnitSyncLib::_ConvertSpringMapInfo( const SpringMapInfo& in, MapInfo&
 
   out.width = in.width;
   out.height = in.height;
-  out.posCount = in.posCount;
-  for ( int i = 0; i < in.posCount; i++) out.positions[i] = in.positions[i];
+  out.positions = std::vector<StartPos>( in.positions, in.positions + in.posCount );
 }
 
 
@@ -1011,6 +1012,14 @@ int SpringUnitSyncLib::GetMapOptionCount( const wxString& name )
   return m_get_map_option_count( name.mb_str( wxConvUTF8 ) );
 }
 
+int SpringUnitSyncLib::GetCustomOptionCount( const wxString& modname, const wxString& filename )
+{
+    InitLib( m_get_custom_option_count );
+    ASSERT_EXCEPTION( !modname.IsEmpty(), _T("passing void XXXname to unitsync") );
+    _SetCurrentMod( modname );
+    return m_get_custom_option_count( filename.mb_str( wxConvUTF8 ) );
+}
+
 
 int SpringUnitSyncLib::GetModOptionCount( const wxString& name )
 {
