@@ -32,22 +32,16 @@
 #include "utils/tasutil.h"
 #include "utils/conversion.h"
 #include "utils/platform.h"
+#include "updater/updatehelper.h"
 #include "battle.h"
 #include "serverevents.h"
 #include "socket.h"
 #include "channel/channel.h"
 #include "tasservertokentable.h"
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif //HAVE_CONFIG_H
-
-#ifndef VERSION
-	#define VERSION "unknown"
-#endif //VERSION
+#include "pingthread.h"
 
 // for SL_MAIN_ICON
-#include "settings++/custom_dialogs.h"
+#include "utils/customdialogs.h"
 
 #include "settings.h"
 
@@ -165,32 +159,32 @@ NatType IntToNatType( int nat );
 IBattle::GameType IntToGameType( int gt );
 
 TASServer::TASServer():
+m_ping_thread(0),
 m_ser_ver(0),
 m_connected(false),
 m_online(false),
 m_debug_dont_catch( false ),
-m_id_transmission( false ),
+m_id_transmission( true ),
 m_redirecting( false ),
 m_buffer(_T("")),
 m_last_udp_ping(0),
 m_last_net_packet(0),
-m_last_id(0),
 m_udp_private_port(0),
 m_battle_id(-1),
+m_server_lanmode(false),
+m_account_id_count(0),
 m_do_finalize_join_battle(false),
 m_finalize_join_battle_id(-1),
 m_token_transmission( false )
 {
-    m_se = new ServerEvents( *this );
+	  m_se = new ServerEvents( *this );
 	  FillAliasMap();
 	  m_relay_host_manager_list.Clear();
 }
 
 TASServer::~TASServer()
 {
-		Disconnect();
-		delete m_sock;
-		m_sock = 0;
+    Disconnect();
     delete m_se;
 }
 
@@ -332,25 +326,19 @@ bool TASServer::ExecuteSayCommand( const wxString& cmd )
 
 void TASServer::Connect( const wxString& servername ,const wxString& addr, const int port )
 {
-		m_server_name = servername;
+	m_server_name = servername;
     m_addr=addr;
-		m_buffer = _T("");
-		m_buffer = _T("");
-    m_sock->Connect( addr, port );
-    if ( IsConnected() )
-    {
-        m_last_udp_ping = time( 0 );
-        m_connected = true;
-    }
-    m_sock->SetPingInfo( _T("PING\n"), 10000 );
-    m_sock->SetSendRateLimit( 800 ); // 1250 is the server limit but 800 just to make sure :)
+	m_buffer = _T("");
+	m_sock->Connect( addr, port );
+	m_sock->SetSendRateLimit( 800 ); // 1250 is the server limit but 800 just to make sure :)
+	m_connected = false;
     m_online = false;
     m_redirecting = false;
     m_agreement = _T("");
-		m_crc.ResetCRC();
-		m_last_net_packet = time( 0 );
-		wxString handle = m_sock->GetHandle();
-		if ( !handle.IsEmpty() ) m_crc.UpdateData( STD_STRING( wxString( handle + m_addr ) ) );
+	m_crc.ResetCRC();
+	m_last_net_packet = time( 0 );
+	wxString handle = m_sock->GetHandle();
+	if ( !handle.IsEmpty() ) m_crc.UpdateData( STD_STRING( wxString( handle + m_addr ) ) );
 }
 
 void TASServer::Disconnect()
@@ -360,33 +348,32 @@ void TASServer::Disconnect()
         return;
     }
     SendCmd( _T("EXIT") ); // EXIT command for new protocol compatibility
-    m_sock->Disconnect();
-    m_connected = false;
+	m_sock->Disconnect();
 }
 
 bool TASServer::IsConnected()
 {
-    return (m_sock->State() == SS_Open);
+	return (m_sock->State() == SS_Open);
 }
 
 
 bool TASServer::Register( const wxString& addr, const int port, const wxString& nick, const wxString& password, wxString& reason )
 {
     wxLogDebugFunc( _T("") );
-		FakeNetClass temp;
-		Socket tempsocket( temp, true );
+	FakeNetClass temp;
+	Socket tempsocket( temp, true, true );
     tempsocket.Connect( addr, port );
     if ( tempsocket.State() != SS_Open ) return false;
 
     wxString data = tempsocket.Receive().BeforeLast(_T('\n'));
-    if ( data.Contains( _T("\r") ) ) data = data.BeforeLast(_T('\r'));
+    if ( data.Find( _T("\r") ) != wxNOT_FOUND ) data = data.BeforeLast(_T('\r'));
     if ( GetWordParam( data ) != _T("TASServer") ) return false;
 
     tempsocket.Send( _T("REGISTER ") + nick + _T(" ") + GetPasswordHash( password ) + _T("\n") );
 
     data = tempsocket.Receive().BeforeLast(_T('\n'));
     tempsocket.Disconnect();
-    if ( data.Contains( _T("\r") ) ) data = data.BeforeLast(_T('\r'));
+    if ( data.Find( _T("\r") ) != wxNOT_FOUND ) data = data.BeforeLast(_T('\r'));
     if ( data.IsEmpty() )
     {
         reason = _("Connection timed out");
@@ -437,8 +424,10 @@ wxString TASServer::GetPasswordHash( const wxString& pass ) const
 }
 
 
-User& TASServer::GetMe() const
-{
+User& TASServer::GetMe() {
+    return GetUser( m_user );
+}
+const User& TASServer::GetMe() const {
     return GetUser( m_user );
 }
 
@@ -449,10 +438,12 @@ void TASServer::Login()
     wxString pass = GetPasswordHash( m_pass );
     wxString protocol = _T("\t") + TowxString( m_crc.GetCRC() );
     wxString localaddr;
-    localaddr = m_sock->GetLocalAddress();
+	localaddr = m_sock->GetLocalAddress();
     if ( localaddr.IsEmpty() ) localaddr = _T("*");
+	m_id_transmission = false;
     SendCmd ( _T("LOGIN"), m_user + _T(" ") + pass + _T(" ") +
-              GetHostCPUSpeed() + _T(" ") + localaddr + _T(" SpringLobby ") + GetSpringLobbyVersion() + protocol  + _T("\ta"));
+			  GetHostCPUSpeed() + _T(" ") + localaddr + _T(" SpringLobby ") + GetSpringLobbyVersion(false) + protocol  + _T("\ta"));
+	m_id_transmission = true;
 }
 
 void TASServer::Logout()
@@ -483,7 +474,7 @@ void TASServer::AcceptAgreement()
 void TASServer::Update( int mselapsed )
 {
 
-    m_sock->OnTimer( mselapsed );
+	m_sock->OnTimer( mselapsed );
 
     if ( !m_connected )   // We are not formally connected yet, but might be.
     {
@@ -574,7 +565,7 @@ void TASServer::ExecuteCommand( const wxString& in )
     }
     if ( params[0] == '#' )
     {
-				wxString id = params.BeforeFirst( ' ' ).AfterFirst( '#' );
+		wxString id = params.BeforeFirst( ' ' ).AfterFirst( '#' );
         params = params.AfterFirst( ' ' );
         id.ToLong( &replyid );
     }
@@ -585,7 +576,7 @@ void TASServer::ExecuteCommand( const wxString& in )
 		wxString copy = cmd;
 		cmd = DecodeTokenMessage( cmd );
 		if ( copy != cmd ) m_token_transmission = true;
-		cmd.UpperCase();
+		cmd.MakeUpper();
 
     if ( m_debug_dont_catch )
     {
@@ -630,9 +621,11 @@ void TASServer::ExecuteCommand( const wxString& cmd, const wxString& inparams, i
     }
     else if ( cmd == _T("ACCEPTED") )
     {
-				if ( m_online ) return; // in case is the server sends WTF
+		if ( m_online ) return; // in case is the server sends WTF
         m_online = true;
         m_user = params;
+		m_ping_thread = new PingThread( *this, 10000 );
+		m_ping_thread->Init();
         m_se->OnLogin( );
     }
     else if ( cmd == _T("MOTD") )
@@ -644,7 +637,16 @@ void TASServer::ExecuteCommand( const wxString& cmd, const wxString& inparams, i
         nick = GetWordParam( params );
         contry = GetWordParam( params );
         cpu = GetIntParam( params );
-				id = GetIntParam( params );
+        if ( params.IsEmpty() )
+        {
+        	// if server didn't send any account id to us, fill with an always increasing number
+        	id = m_account_id_count;
+        	m_account_id_count++;
+        }
+        else
+        {
+					id = GetIntParam( params );
+        }
         m_se->OnNewUser( nick, contry, cpu, TowxString(id) );
         if ( nick == m_relay_host_bot )
         {
@@ -701,13 +703,10 @@ void TASServer::ExecuteCommand( const wxString& cmd, const wxString& inparams, i
     {
 				if ( sett().GetReportStats() )
 				{
-					wxString version = WX_STRINGC(VERSION).BeforeFirst( _T(' ') );
-					wxString aux;
-					#ifdef AUX_VERSION
-						aux = WX_STRINGC(AUX_VERSION);
-						aux.Replace( _T(" "), _T("") );
-						aux = _T(" ") + aux;
-					#endif
+					wxString version = GetSpringLobbyVersion(false);
+					wxString aux = GetSpringLobbyAuxVersion();
+					aux.Replace( _T(" "), _T("") );
+					aux = _T(" ") + aux;
 					wxString os = wxPlatformInfo::Get().GetOperatingSystemIdName();
 					os.Replace( _T(" "), _T("") );
 					wxString wxversion = wxVERSION_STRING;
@@ -935,7 +934,7 @@ void TASServer::ExecuteCommand( const wxString& cmd, const wxString& inparams, i
         bstatus = ConvTasbattlestatus( tasbstatus.tasdata );
         color.data = GetIntParam( params );
         bstatus.colour = wxColour( color.color.red, color.color.green, color.color.blue );
-        wxString ai = GetSentenceParam( params );
+        ai = GetSentenceParam( params );
         if ( ai.IsEmpty() ) {
             wxLogWarning( wxString::Format( _T("Recieved illegal ADDBOT (empty dll field) from %s for battle %d"), nick.c_str(), id ) );
             ai = _T("INVALID|INVALID");
@@ -1045,8 +1044,8 @@ void TASServer::ExecuteCommand( const wxString& cmd, const wxString& inparams, i
         // clientipport username ip port
         nick=GetWordParam( params );
         wxString ip=GetWordParam(params);
-        unsigned int port=(unsigned int)GetIntParam( params );
-        m_se->OnClientIPPort(nick, ip, port);
+        unsigned int u_port=(unsigned int)GetIntParam( params );
+        m_se->OnClientIPPort(nick, ip, u_port);
     }
     else if ( cmd == _T("SETSCRIPTTAGS") )
     {
@@ -1092,11 +1091,11 @@ void TASServer::ExecuteCommand( const wxString& cmd, const wxString& inparams, i
     {
         if ( m_online ) return;
         wxString address = GetWordParam( params );
-        unsigned int port = GetIntParam( params );
+        unsigned int u_port = GetIntParam( params );
         if ( address.IsEmpty() ) return;
-        if ( port == 0 ) port = DEFSETT_DEFAULT_SERVER_PORT;
+        if ( u_port  == 0 ) u_port  = DEFSETT_DEFAULT_SERVER_PORT;
         m_redirecting = true;
-        m_se->OnRedirect( address, port, m_user, m_pass );
+        m_se->OnRedirect( address, u_port , m_user, m_pass );
     }
     else if ( cmd == _T("MUTELISTBEGIN") )
     {
@@ -1153,8 +1152,8 @@ void TASServer::SendCmd( const wxString& command, const wxString& param )
 		wxString cmd, msg;
 		if ( m_id_transmission )
 		{
-			 m_last_id++;
-			 msg = msg + _T("#") + TowxString( m_last_id ) + _T(" ");
+			 GetLastID()++;
+			 msg = msg + _T("#") + TowxString( GetLastID() ) + _T(" ");
 		}
 		if ( m_token_transmission )
 		{
@@ -1163,29 +1162,32 @@ void TASServer::SendCmd( const wxString& command, const wxString& param )
 		else cmd = command;
 		if ( param.IsEmpty() ) msg = msg + cmd + _T("\n");
 		else msg = msg + cmd + _T(" ") + param + _T("\n");
-		m_sock->Send( msg );
-		wxLogMessage( _T("sent: %s"), msg.c_str() );
+		bool send_success = m_sock->Send( msg );
+		if ( command != _T("PING") )
+		{
+			if ( send_success )
+				wxLogMessage( _T("sent: %s"), msg.c_str() );
+			else
+				wxLogMessage( _T("sending: %s failed"), msg.c_str() );
+		}
 }
 
 void TASServer::Ping()
 {
-    //wxLogDebugFunc( _T("") );
-		m_id_transmission = true;
-		SendCmd( _T("PING") );
-		m_id_transmission = false;
-    TASPingListItem pli;
-    pli.id = m_last_id;
-    pli.t = wxGetLocalTimeMillis();
-    m_pinglist.push_back ( pli );
+	SendCmd( _T("PING") );
+	TASPingListItem pli;
+	pli.id = GetLastID();
+	pli.t = wxGetLocalTimeMillis();
+	GetPingList().push_back ( pli );
 }
 
-
 void TASServer::HandlePong( int replyid )
 {
-    std::list<TASPingListItem>::iterator it;
+	PingList& pinglistcopy = GetPingList();
+	PingList::iterator it;
 
     bool found = false;
-    for ( it = m_pinglist.begin(); it != m_pinglist.end(); it++ )
+	for ( it = pinglistcopy.begin(); it != pinglistcopy.end(); it++ )
     {
         if (it->id == replyid )
         {
@@ -1197,7 +1199,7 @@ void TASServer::HandlePong( int replyid )
     if ( found )
     {
         m_se->OnPong( (wxGetLocalTimeMillis() - it->t) );
-        m_pinglist.erase( it );
+		pinglistcopy.erase( it );
     }
 }
 
@@ -1208,8 +1210,9 @@ void TASServer::JoinChannel( const wxString& channel, const wxString& key )
     wxLogDebugFunc( channel );
 
     m_channel_pw[channel] = key;
-
+	m_id_transmission = false; // workaround a retarded server bug
     SendCmd ( _T("JOIN"), channel + _T(" ") + key );
+	m_id_transmission = true;
 }
 
 
@@ -1277,8 +1280,28 @@ void TASServer::DoActionBattle( int /*unused*/, const wxString& msg )
 void TASServer::Ring( const wxString& nick )
 {
     wxLogDebugFunc( _T("") );
+		try
+		{
+				ASSERT_EXCEPTION( m_battle_id != -1, _T("invalid m_battle_id value") );
+				ASSERT_EXCEPTION( BattleExists(m_battle_id), _T("battle doesn't exists") );
 
-    SendCmd( _T("RING"), nick );
+				Battle& battle = GetBattle( m_battle_id );
+				ASSERT_EXCEPTION( battle.IsFounderMe(), _T("I'm not founder") );
+
+				if ( battle.IsProxy() )
+				{
+					RelayCmd( _T("RING"), nick );
+				}
+				else
+				{
+					SendCmd( _T("RING"), nick );
+				}
+
+		}
+		catch (...)
+		{
+			SendCmd( _T("RING"), nick );
+		}
 }
 
 
@@ -1642,7 +1665,6 @@ void TASServer::SendHostInfo( const wxString& Tag )
 
     try
     {
-        Battle& battle = GetBattle( m_battle_id );
         ASSERT_LOGIC( battle.IsFounderMe(), _T("I'm not founder") );
     }
     catch (...)
@@ -1736,8 +1758,6 @@ void TASServer::SendMyBattleStatus( UserBattleStatus& bs )
 {
     wxLogDebugFunc( _T("") );
 
-    GetMe().UpdateBattleStatus( bs );
-
     UTASBattleStatus tasbs;
     tasbs.tasdata = ConvTasbattlestatus( bs );
     UTASColor tascl;
@@ -1807,7 +1827,7 @@ void TASServer::ForceSide( int battleid, User& user, int side )
         return;
     }
 
-		UserBattleStatus& status = user.BattleStatus();
+		UserBattleStatus status = user.BattleStatus();
 
     if ( &user == &GetMe() )
     {
@@ -1837,16 +1857,17 @@ void TASServer::ForceTeam( int battleid, User& user, int team )
     {
         return;
     }
-		if ( user.BattleStatus().IsBot() )
+    UserBattleStatus status = user.BattleStatus();
+		if ( status.IsBot() )
 		{
-				user.BattleStatus().team = team;
-				UpdateBot( battleid, user, user.BattleStatus() );
+				status.team = team;
+				UpdateBot( battleid, user, status );
 				return;
 		}
 		if ( &user == &GetMe() )
 		{
-				GetMe().BattleStatus().team = team;
-				SendMyBattleStatus( GetMe().BattleStatus() );
+				status.team = team;
+				SendMyBattleStatus( status );
 				return;
 		}
     if ( !GetBattle(battleid).IsFounderMe() )
@@ -1874,18 +1895,18 @@ void TASServer::ForceAlly( int battleid, User& user, int ally )
     {
         return;
     }
-
-		if ( user.BattleStatus().IsBot() )
+		UserBattleStatus status = user.BattleStatus();
+		if ( status.IsBot() )
 		{
-			 user.BattleStatus().ally = ally;
-			 UpdateBot( battleid, user, user.BattleStatus() );
+			 status.ally = ally;
+			 UpdateBot( battleid, user, status );
 			 return;
 		}
 
 		if ( &user == &GetMe() )
 		{
-				GetMe().BattleStatus().ally = ally;
-				SendMyBattleStatus( GetMe().BattleStatus() );
+				status.ally = ally;
+				SendMyBattleStatus( status );
 				return;
 		}
 
@@ -1914,17 +1935,17 @@ void TASServer::ForceColour( int battleid, User& user, const wxColour& col )
     {
         return;
     }
-
-		if ( user.BattleStatus().IsBot() )
+		UserBattleStatus status = user.BattleStatus();
+		if ( status.IsBot() )
 		{
-			 user.BattleStatus().colour = col;
-			 UpdateBot( battleid, user, user.BattleStatus() );
+			 status.colour = col;
+			 UpdateBot( battleid, user, status );
 			 return;
 		}
 		if ( &user == &GetMe() )
 		{
-				GetMe().BattleStatus().colour = col;
-				SendMyBattleStatus( GetMe().BattleStatus() );
+				status.colour = col;
+				SendMyBattleStatus( status );
 				return;
 		}
     if ( !GetBattle(battleid).IsFounderMe() )
@@ -1957,17 +1978,17 @@ void TASServer::ForceSpectator( int battleid, User& user, bool spectator )
     {
         return;
     }
-
-		if ( user.BattleStatus().IsBot() )
+		UserBattleStatus status = user.BattleStatus();
+		if ( status.IsBot() )
 		{
-			 user.BattleStatus().spectator = spectator;
-			 UpdateBot( battleid, user, user.BattleStatus() );
+			 status.spectator = spectator;
+			 UpdateBot( battleid, user, status );
 			 return;
 		}
 		if ( &user == &GetMe() )
 		{
-				GetMe().BattleStatus().spectator = spectator;
-				SendMyBattleStatus( GetMe().BattleStatus() );
+				status.spectator = spectator;
+				SendMyBattleStatus( status );
 				return;
 		}
     if ( !GetBattle(battleid).IsFounderMe() )
@@ -1996,8 +2017,8 @@ void TASServer::BattleKickPlayer( int battleid, User& user )
     {
         return;
     }
-
-    if ( user.BattleStatus().IsBot() )
+		UserBattleStatus status = user.BattleStatus();
+    if ( status.IsBot() )
     {
     	RemoveBot( battleid, user );
     	return;
@@ -2031,11 +2052,11 @@ void TASServer::SetHandicap( int battleid, User& user, int handicap)
     {
         return;
     }
-
-		if ( user.BattleStatus().IsBot() )
+		UserBattleStatus status = user.BattleStatus();
+		if ( status.IsBot() )
 		{
-				user.BattleStatus().handicap = handicap;
-				UpdateBot( battleid, user, user.BattleStatus() );
+				status.handicap = handicap;
+				UpdateBot( battleid, user, status );
 				return;
 		}
 
@@ -2167,9 +2188,11 @@ void TASServer::OnConnected( Socket* /*unused*/ )
     m_last_udp_ping = time( 0 );
     m_connected = true;
     m_online = false;
-		m_token_transmission = false;
-		m_relay_host_manager_list.Clear();
-		m_last_denied = _T("");
+	m_token_transmission = false;
+	m_relay_host_manager_list.Clear();
+	m_last_denied = _T("");
+	GetLastID() = 0;
+	GetPingList().clear();
 }
 
 
@@ -2181,9 +2204,18 @@ void TASServer::OnDisconnected( Socket* /*unused*/ )
     m_connected = false;
     m_online = false;
     m_redirecting = false;
-		m_token_transmission = false;
-		m_buffer = _T("");
-		m_relay_host_manager_list.Clear();
+	m_token_transmission = false;
+	m_buffer = _T("");
+	m_relay_host_manager_list.Clear();
+	GetLastID() = 0;
+	GetPingList().clear();
+	if ( m_ping_thread )
+	{
+		m_ping_thread->Wait();
+		delete m_ping_thread;
+		m_ping_thread = 0;
+	}
+	m_users.Nullify();
     m_se->OnDisconnected( connectionwaspresent );
     Server::OnDisconnected();
 }
@@ -2239,7 +2271,9 @@ unsigned int TASServer::UdpPing(unsigned int src_port, const wxString &target, u
         wxLogMessage(_T("socket's IsOk() is false, no UDP ping done."));
     }
 
-    if (udp_socket.Error())wxLogWarning(_T("wxDatagramSocket Error=%d"),udp_socket.LastError());
+    if (udp_socket.Error()) {
+        wxLogWarning(_T("wxDatagramSocket Error=%d"),udp_socket.LastError());
+    }
     return result;
 }
 
@@ -2321,7 +2355,7 @@ void TASServer::UdpPingAllClients()// used when hosting with nat holepunching. h
 
 
 //! @brief used to check if the NAT is done properly when hosting
-int TASServer::TestOpenPort( unsigned int port )
+int TASServer::TestOpenPort( unsigned int port ) const
 {
     wxIPV4address local_addr;
     local_addr.AnyAddress(); // <--- THATS ESSENTIAL!
@@ -2359,6 +2393,7 @@ void TASServer::RequestSpringUpdate()
 
 wxArrayString TASServer::GetRelayHostList()
 {
+	if ( UserExists( _T("RelayHostManagerList") ) ) SayPrivate( _T("RelayHostManagerList"), _T("!listmanagers") );
 	wxArrayString ret;
 	for ( unsigned int i = 0; i < m_relay_host_manager_list.GetCount(); i++ )
 	{
