@@ -18,6 +18,7 @@
 #include <wx/utils.h>
 #include <wx/debugrpt.h>
 #include <wx/filename.h>
+#include <wx/app.h>
 
 #include "ui.h"
 #include "tasserver.h"
@@ -30,6 +31,9 @@
 #include "user.h"
 #include "utils/debug.h"
 #include "utils/conversion.h"
+#include "utils/uievents.h"
+#include "updater/updatehelper.h"
+#include "uiutils.h"
 #include "chatpanel.h"
 #include "battlelisttab.h"
 #include "battleroomtab.h"
@@ -41,20 +45,24 @@
 #include "maintorrenttab.h"
 #include "torrentwrapper.h"
 #endif
-#include "unitsyncthread.h"
+
 #include "agreementdialog.h"
 #ifdef __WXMSW__
-#include "updater/updater.h"
+    #include "updater/updatehelper.h"
+    #include "Helper/tasclientimport.h"
+    #include <wx/stdpaths.h>
 #endif
 
-#include "settings++/custom_dialogs.h"
-
-#include "sdlsound.h"
+#include "utils/customdialogs.h"
+#include "utils/platform.h"
+#include "updater/versionchecker.h"
+#include "alsound.h"
 #include "globalsmanager.h"
 
 Ui& ui()
 {
-    static GlobalObjectHolder<Ui> m_ui;
+    static LineInfo<Ui> m( AT );
+    static GlobalObjectHolder<Ui,LineInfo<Ui> > m_ui( m );
     return m_ui;
 }
 
@@ -66,7 +74,7 @@ Ui::Ui() :
         m_first_update_trigger(true),
         m_ingame(false)
 {
-    m_main_win = new MainWindow( *this );
+    m_main_win = new MainWindow( );
     CustomMessageBoxBase::setLobbypointer(m_main_win);
     m_serv = new TASServer();
 }
@@ -84,7 +92,13 @@ Server& Ui::GetServer()
     return *m_serv;
 }
 
-bool Ui::GetServerStatus()
+const Server& Ui::GetServer() const
+{
+    ASSERT_LOGIC( m_serv != 0, _T("m_serv NULL!") );
+    return *m_serv;
+}
+
+bool Ui::GetServerStatus() const
 {
     return (bool)(m_serv);
 }
@@ -103,7 +117,7 @@ MainWindow& Ui::mw()
 }
 
 
-bool Ui::IsMainWindowCreated()
+bool Ui::IsMainWindowCreated() const
 {
     if ( m_main_win == 0 ) return false;
     else return true;
@@ -263,16 +277,7 @@ void Ui::JoinChannel( const wxString& name, const wxString& password )
 }
 
 
-void Ui::StartHostedBattle()
-{
-    ASSERT_LOGIC( m_serv != 0, _T("m_serv = 0") );
-    GetServer().StartHostedBattle();
-    sett().SetLastHostMap( GetServer().GetCurrentBattle()->GetHostMapName() );
-    sett().SaveSettings();
-}
-
-
-bool Ui::IsSpringRunning()
+bool Ui::IsSpringRunning() const
 {
     return spring().IsRunning();
 }
@@ -282,98 +287,48 @@ bool Ui::IsSpringRunning()
 void Ui::Quit()
 {
     Disconnect();
-
-    #ifndef NO_TORRENT_SYSTEM
-        torrent().DisconnectFromP2PSystem();// Cant hurt to disconnect unconditionally.
-    #endif
-
     if ( m_con_win != 0 )
         m_con_win->Close();
 }
 
-
-void Ui::ReloadUnitSync()
-{
-    usync().ReloadUnitSyncLib();
-    if ( m_main_win != 0 ) mw().OnUnitSyncReloaded();
-}
-
-
-void Ui::DownloadMap( const wxString& hash, const wxString& name )
+void Ui::DownloadMap( const wxString& /*hash*/, const wxString& name )
 {
 #ifndef NO_TORRENT_SYSTEM
-    DownloadFileP2P( hash, name );
+    DownloadFileP2P( name );
 #else
-		wxString newname = name;
-		newname.Replace( _T(" "), _T("+") );
-    wxString url = _T(" http://spring.jobjol.nl/search_result.php?search_cat=1&select_select=select_file_subject&Submit=Search&search=") + newname;
-    OpenWebBrowser ( url );
+	DownloadFileWebsite( name );
 #endif
 }
 
 
-void Ui::DownloadMod( const wxString& hash, const wxString& name )
+void Ui::DownloadMod( const wxString& /*hash*/, const wxString& name )
 {
 #ifndef NO_TORRENT_SYSTEM
-    DownloadFileP2P( hash, name );
+    DownloadFileP2P( name );
 #else
-		wxString newname = name;
-		newname.Replace( _T(" "), _T("+") );
-    wxString url = _T(" http://spring.jobjol.nl/search_result.php?search_cat=1&select_select=select_file_subject&Submit=Search&search=") + newname;
-    OpenWebBrowser ( url );
+	DownloadFileWebsite( name );
 #endif
 }
 
-void Ui::DownloadFileP2P( const wxString& hash, const wxString& name )
+void Ui::DownloadFileP2P( const wxString& name )
 {
 #ifndef NO_TORRENT_SYSTEM
-    if ( !torrent().IsConnectedToP2PSystem() ){
-        wxArrayString hashesToResume = sett().GetTorrentListToResume();
-        hashesToResume.Add( hash );
-        sett().SetTorrentListToResume( hashesToResume );
-        torrent().ConnectToP2PSystem();
-    }
-    else {
-
-    //we need a way to have the request happen only after connect is complete
-        TorrentWrapper::DownloadRequestStatus status;
-        if ( !hash.IsEmpty() ) {
-             status = torrent().RequestFileByHash( hash );
-        }
-        else if ( !name.IsEmpty() )
-            status = torrent().RequestFileByName( name );
-
-//!TODO: put some meaningful err msg here
-//        if ( status != TorrentWrapper::success ){
-//            customMessageBoxNoModal( SL_MAIN_ICON, _(""), _("") );
-//        }
-    }
+	if ( usync().IsLoaded() )
+		torrent().RequestFileByName( name );
+	else
+	{
+		customMessageBoxNoModal( SL_MAIN_ICON, _("To use the integrated downloader the unitsync library needs to be loaded.\n" \
+												 "Please check for correct path in Edit->Preferences->Spring"), _("Unitsync not loaded") );
+	}
 #endif
 }
 
-
-void Ui::OpenWebBrowser( const wxString& url )
+void Ui::DownloadFileWebsite( const wxString& name )
 {
-    if ( sett().GetWebBrowserUseDefault()
-            // These shouldn't happen, but if they do we use the default browser anyway.
-            || sett().GetWebBrowserPath() == wxEmptyString
-            || sett().GetWebBrowserPath() == _T("use default") )
-    {
-        if ( !wxLaunchDefaultBrowser( url ) )
-        {
-            wxLogWarning( _T("can't launch default browser") );
-            customMessageBoxNoModal(SL_MAIN_ICON, _("Couldn't launch browser. URL is: ") + url, _("Couldn't launch browser.")  );
-        }
-    }
-    else
-    {
-        if ( !wxExecute ( sett().GetWebBrowserPath() + _T(" ") + url, wxEXEC_ASYNC ) )
-        {
-            wxLogWarning( _T("can't launch browser: %s"), sett().GetWebBrowserPath().c_str() );
-            customMessageBoxNoModal(SL_MAIN_ICON, _("Couldn't launch browser. URL is: ") + url + _("\nBroser path is: ") + sett().GetWebBrowserPath(), _("Couldn't launch browser.")  );
-        }
-
-    }
+	wxString newname = name;
+	newname.Replace( _T(" "), _T("+") );
+	wxString url = _T(" http://spring.jobjol.nl/search_result.php?search_cat=1&select_select=select_file_subject&Submit=Search&search=") + newname;
+	OpenWebBrowser ( url );
 }
 
 
@@ -409,16 +364,13 @@ bool Ui::AskText( const wxString& heading, const wxString& question, wxString& a
 
 void Ui::ShowMessage( const wxString& heading, const wxString& message )
 {
-
     if ( m_main_win == 0 ) return;
     serverMessageBox( SL_MAIN_ICON, message, heading, wxOK);
-
 }
 
 
 bool Ui::ExecuteSayCommand( const wxString& cmd )
 {
-
     if ( !IsConnected() ) return false;
     //TODO insert logic for joining multiple channels at once
     //or remove that from "/help"
@@ -550,19 +502,17 @@ void Ui::OnUpdate( int mselapsed )
             mw().ShowTab( sett().GetStartTab() );
         }
 #ifdef __WXMSW__
-        if ( sett().GetAutoUpdate() )Updater().CheckForUpdates();
+        if ( sett().GetAutoUpdate() )
+            CheckForUpdates();
 #endif
     }
 
 #ifndef NO_TORRENT_SYSTEM
     if (m_upd_counter_torrent % 20 == 0 )
     {
-        if ( sett().GetTorrentSystemAutoStartMode() == 1 && !torrent().IsConnectedToP2PSystem() ) torrent().ConnectToP2PSystem();
-        else if ( GetServerStatus() && GetServer().IsOnline() && !torrent().IsConnectedToP2PSystem() && sett().GetTorrentSystemAutoStartMode() == 0 ) torrent().ConnectToP2PSystem();
-        if ( ( !GetServerStatus() || !GetServer().IsOnline() ) && torrent().IsConnectedToP2PSystem() && sett().GetTorrentSystemAutoStartMode() == 0 ) torrent().DisconnectFromP2PSystem();
         mw().GetTorrentTab().OnUpdate();
     }
-    torrent().UpdateFromTimer( mselapsed );
+//    torrent().UpdateFromTimer( mselapsed );
     m_upd_counter_torrent++;
 #endif
 }
@@ -571,7 +521,7 @@ void Ui::OnUpdate( int mselapsed )
 //! @brief Called when connected to a server
 //!
 //! @todo Display in servertab
-void Ui::OnConnected( Server& server, const wxString& server_name, const wxString& /*unused*/, bool supported )
+void Ui::OnConnected( Server& server, const wxString& server_name, const wxString& /*unused*/, bool /*supported*/ )
 {
     wxLogDebugFunc( _T("") );
     if ( !m_last_used_backup_server.IsEmpty() )
@@ -590,8 +540,7 @@ void Ui::OnConnected( Server& server, const wxString& server_name, const wxStrin
     }
 
     if ( server.uidata.panel ) server.uidata.panel->StatusMessage( _T("Connected to ") + server_name + _T(".") );
-    mw().GetJoinTab().OnConnected();
-
+		mw().GetBattleListTab().OnConnected();
 }
 
 
@@ -617,7 +566,7 @@ bool Ui::IsSpringCompatible()
         {
           wxLogMessage(_T("server enforce usage of version: %s, switching to profile: %s"), neededversion.c_str(), itor->first.c_str() );
           sett().SetUsedSpringIndex( itor->first );
-          ReloadUnitSync();
+		  usync().AddReloadEvent();
         }
         return true;
       }
@@ -652,20 +601,28 @@ void Ui::OnDisconnected( Server& server, bool wasonline )
     }
 
     mw().GetJoinTab().LeaveCurrentBattle();
-    mw().GetJoinTab().GetBattleListTab().RemoveAllBattles();
+    mw().GetBattleListTab().RemoveAllBattles();
 
     mw().GetChatTab().LeaveChannels();
 
+	wxString disconnect_msg = wxString::Format(_("disconnected from server: %s"), server.GetServerName().c_str() );
+	UiEvents::GetStatusEventSender( UiEvents::addStatusMessage ).SendEvent(
+			UiEvents::StatusData( disconnect_msg, 1 ) );
+	if ( sett().GetUseNotificationPopups() && !wxTheApp->IsActive() )
+	{
+		UiEvents::GetNotificationEventSender().SendEvent(
+				UiEvents::NotficationData( wxNullBitmap, disconnect_msg ) );
+	}
     if ( server.uidata.panel )
     {
-        server.uidata.panel->StatusMessage( _("Disconnected from server.") );
+		server.uidata.panel->StatusMessage( disconnect_msg );
 
         server.uidata.panel->SetServer( 0 );
     }
-		if ( !wasonline ) // couldn't even estabilish a socket, prompt the user to switch to another server
-		{
-			ConnectionFailurePrompt();
-		}
+	if ( !wasonline ) // couldn't even estabilish a socket, prompt the user to switch to another server
+	{
+		ConnectionFailurePrompt();
+	}
 }
 
 void Ui::ConnectionFailurePrompt()
@@ -878,7 +835,13 @@ void Ui::OnUserStatusChanged( User& user )
             chan.uidata.panel->UserStatusUpdated( user );
         }
     }
-    if ( user.GetStatus().in_game ) mw().GetJoinTab().GetBattleListTab().UserUpdate( user );
+    if ( user.GetStatus().in_game ) mw().GetBattleListTab().UserUpdate( user );
+    try
+    {
+			ChatPanel& server = mw().GetChatTab().ServerChat();
+			server.UserStatusUpdated( user );
+		}
+		catch(...){}
 }
 
 
@@ -919,26 +882,29 @@ void Ui::OnUserSaid( User& user, const wxString& message, bool fromme )
 void Ui::OnBattleOpened( IBattle& battle )
 {
     if ( m_main_win == 0 ) return;
-    mw().GetJoinTab().GetBattleListTab().AddBattle( battle );
-    User& user = battle.GetFounder();
-    for ( int i = 0; i < GetServer().GetNumChannels(); i++ )
+    mw().GetBattleListTab().AddBattle( battle );
+    try
     {
-        Channel& chan = GetServer().GetChannel( i );
-        if ( ( chan.UserExists(user.GetNick()) ) && ( chan.uidata.panel != 0 ) )
-        {
-            chan.uidata.panel->UserStatusUpdated( user );
-        }
-    }
+			User& user = battle.GetFounder();
+			for ( int i = 0; i < GetServer().GetNumChannels(); i++ )
+			{
+					Channel& chan = GetServer().GetChannel( i );
+					if ( ( chan.UserExists(user.GetNick()) ) && ( chan.uidata.panel != 0 ) )
+					{
+							chan.uidata.panel->UserStatusUpdated( user );
+					}
+			}
+    }catch(...){}
 }
 
 
 void Ui::OnBattleClosed( IBattle& battle )
 {
     if ( m_main_win == 0 ) return;
-    mw().GetJoinTab().GetBattleListTab().RemoveBattle( battle );
+    mw().GetBattleListTab().RemoveBattle( battle );
     try
     {
-        if ( &mw().GetJoinTab().GetBattleRoomTab().GetBattle() == &battle )
+        if ( mw().GetJoinTab().GetBattleRoomTab().GetBattle() == &battle )
         {
             if (!battle.IsFounderMe() )
                 customMessageBoxNoModal(SL_MAIN_ICON,_("The current battle was closed by the host."),_("Battle closed"));
@@ -965,11 +931,11 @@ void Ui::OnBattleClosed( IBattle& battle )
 void Ui::OnUserJoinedBattle( IBattle& battle, User& user )
 {
     if ( m_main_win == 0 ) return;
-    mw().GetJoinTab().GetBattleListTab().UpdateBattle( battle );
+    mw().GetBattleListTab().UpdateBattle( battle );
 
     try
     {
-        if ( &mw().GetJoinTab().GetBattleRoomTab().GetBattle() == &battle )
+        if ( mw().GetJoinTab().GetBattleRoomTab().GetBattle() == &battle )
         {
         	 mw().GetJoinTab().GetBattleRoomTab().OnUserJoined( user );
         	 OnBattleInfoUpdated( battle );
@@ -993,10 +959,10 @@ void Ui::OnUserLeftBattle( IBattle& battle, User& user )
     if ( m_main_win == 0 ) return;
     user.SetSideiconIndex( -1 ); //just making sure he's not running around with some icon still set
 	user.BattleStatus().side = 0; // and reset side, so after rejoin we don't potentially stick with a num higher than avail
-    mw().GetJoinTab().GetBattleListTab().UpdateBattle( battle );
+    mw().GetBattleListTab().UpdateBattle( battle );
     try
     {
-        if ( &mw().GetJoinTab().GetBattleRoomTab().GetBattle() == &battle )
+        if ( mw().GetJoinTab().GetBattleRoomTab().GetBattle() == &battle )
         {
             mw().GetJoinTab().GetBattleRoomTab().OnUserLeft( user );
 						OnBattleInfoUpdated( battle );
@@ -1021,7 +987,7 @@ void Ui::OnUserLeftBattle( IBattle& battle, User& user )
 void Ui::OnBattleInfoUpdated( IBattle& battle )
 {
     if ( m_main_win == 0 ) return;
-    mw().GetJoinTab().GetBattleListTab().UpdateBattle( battle );
+    mw().GetBattleListTab().UpdateBattle( battle );
     if ( mw().GetJoinTab().GetCurrentBattle() == &battle )
     {
         mw().GetJoinTab().UpdateCurrentBattle();
@@ -1031,7 +997,7 @@ void Ui::OnBattleInfoUpdated( IBattle& battle )
 void Ui::OnBattleInfoUpdated( IBattle& battle, const wxString& Tag )
 {
     if ( m_main_win == 0 ) return;
-    mw().GetJoinTab().GetBattleListTab().UpdateBattle( battle );
+    mw().GetBattleListTab().UpdateBattle( battle );
     if ( mw().GetJoinTab().GetCurrentBattle() == &battle )
     {
         mw().GetJoinTab().UpdateCurrentBattle( Tag );
@@ -1043,6 +1009,7 @@ void Ui::OnJoinedBattle( Battle& battle )
 {
     if ( m_main_win == 0 ) return;
     mw().GetJoinTab().JoinBattle( battle );
+    mw().FocusBattleRoomTab();
     if ( !usync().IsLoaded() )
     {
         customMessageBox(SL_MAIN_ICON, _("Your spring settings are probably not configured correctly,\nyou should take another look at your settings before trying\nto play online."), _("Spring settings error"), wxOK );
@@ -1056,8 +1023,10 @@ void Ui::OnJoinedBattle( Battle& battle )
 
 void Ui::OnHostedBattle( Battle& battle )
 {
-    if ( m_main_win == 0 ) return;
+	if ( m_main_win == 0 )
+		return;
     mw().GetJoinTab().HostBattle( battle );
+	mw().FocusBattleRoomTab();
 }
 
 
@@ -1074,9 +1043,9 @@ void Ui::OnRequestBattleStatus( IBattle& battle )
     if ( m_main_win == 0 ) return;
     try
     {
-        if ( &mw().GetJoinTab().GetBattleRoomTab().GetBattle() == &battle )
+        if ( mw().GetJoinTab().GetBattleRoomTab().GetBattle() == &battle )
         {
-            mw().GetJoinTab().GetBattleRoomTab().GetBattle().OnRequestBattleStatus();
+            mw().GetJoinTab().GetBattleRoomTab().GetBattle()->OnRequestBattleStatus();
         }
     }
     catch (...) {}
@@ -1087,7 +1056,7 @@ void Ui::OnBattleStarted( Battle& battle )
 {
     if ( m_main_win == 0 ) return;
     wxLogDebugFunc( _T("") );
-    mw().GetJoinTab().GetBattleListTab().UpdateBattle( battle );
+    mw().GetBattleListTab().UpdateBattle( battle );
 }
 
 
@@ -1173,11 +1142,17 @@ void Ui::OnAcceptAgreement( const wxString& agreement )
 }
 
 
-void Ui::OnRing( const wxString& /*from */)
+void Ui::OnRing( const wxString& from )
 {
     if ( m_main_win == 0 ) return;
     m_main_win->RequestUserAttention();
 
+	if ( sett().GetUseNotificationPopups() && !wxTheApp->IsActive() )
+	{
+		UiEvents::GetNotificationEventSender().SendEvent(
+				UiEvents::NotficationData( wxNullBitmap, wxString::Format(_("%s:\nring!"),from.c_str()) ) );
+	}
+
 #ifndef DISABLE_SOUND
     if ( sett().GetChatPMSoundNotificationEnabled() )
         sound().ring();
@@ -1186,42 +1161,17 @@ void Ui::OnRing( const wxString& /*from */)
 #endif
 }
 
-
-void Ui::OnMapInfoCached( const wxString& /*unused*/ )
-{
-    if ( m_main_win == 0 ) return;
-    mw().OnUnitSyncReloaded();
-}
-
-
-void Ui::OnMinimapCached( const wxString& /*unused*/ )
-{
-    if ( m_main_win == 0 ) return;
-    mw().OnUnitSyncReloaded();
-}
-
-
-void Ui::OnModUnitsCached( const wxString& /*unused*/ )
-{
-}
-
-void Ui::OnMainWindowDestruct()
-{
-    //this is rather ugly and therefore disabled
-    //m_main_win = 0;
-}
-
-bool Ui::IsThisMe(User& other)
+bool Ui::IsThisMe(User& other) const
 {
     return IsThisMe( other.GetNick() );
 }
 
-bool Ui::IsThisMe(User* other)
+bool Ui::IsThisMe(User* other) const
 {
     return ( ( other != 0 ) && IsThisMe( other->GetNick() ) );
 }
 
-bool Ui::IsThisMe(const wxString& other)
+bool Ui::IsThisMe(const wxString& other) const
 {
     //if i'm not connected i have no identity
     if (!IsConnected() || m_serv==0)
@@ -1230,7 +1180,7 @@ bool Ui::IsThisMe(const wxString& other)
         return ( other == GetServer().GetMe().GetNick() );
 }
 
-int Ui::TestHostPort( unsigned int port )
+int Ui::TestHostPort( unsigned int port ) const
 {
     return GetServer().TestOpenPort( port );
 }
@@ -1277,5 +1227,94 @@ void Ui::OpenFileInEditor( const wxString& filepath )
         customMessageBoxNoModal( SL_MAIN_ICON, _T("There was a problem launching the editor.\nPlease make sure the path is correct and the binary executable for your user.\nNote it's currently not possible to use shell-only editors like ed, vi, etc."), _T("Problem launching editor") );
         mw().ShowConfigure( MainWindow::OPT_PAGE_GENERAL );
     }
+}
 
+void Ui::FirstRunWelcome()
+{
+    if ( sett().IsFirstRun() )
+    {
+#ifdef __WXMSW__
+        sett().SetOldSpringLaunchMethod( true );
+#endif
+
+        wxLogMessage( _T("first time startup"));
+        wxMessageBox(_("Hi ") + wxGetUserName() + _(",\nIt looks like this is your first time using SpringLobby. I have guessed a configuration that I think will work for you but you should review it, especially the Spring configuration. \n\nWhen you are done you can go to the File menu, connect to a server, and enjoy a nice game of Spring :)"), _("Welcome"),
+                     wxOK | wxICON_INFORMATION, &mw() );
+
+
+        customMessageBoxNoModal(SL_MAIN_ICON, _("By default SpringLobby reports some usage statistics.\nYou can disable that on options tab --> General."),_("Notice"),wxOK );
+
+
+                // copy uikeys.txt
+                wxPathList pl;
+                pl.AddEnvList( _T("%ProgramFiles%") );
+                pl.AddEnvList( _T("XDG_DATA_DIRS") );
+                pl = sett().GetAdditionalSearchPaths( pl );
+                wxString uikeyslocation = pl.FindValidPath( _T("uikeys.txt") );
+                if ( !uikeyslocation.IsEmpty() )
+                {
+                    wxCopyFile( uikeyslocation, sett().GetCurrentUsedDataDir() + wxFileName::GetPathSeparator() + _T("uikeys.txt"), false );
+                }
+
+    #ifdef __WXMSW__
+        if ( TASClientPresent() &&
+                customMessageBox(SL_MAIN_ICON, _("Should I try to import (some) TASClient settings?\n" ),_("Import settings?"), wxYES_NO ) == wxYES )
+        {
+            ImportTASClientSettings();
+        }
+    #endif
+        //this ensures that for new configs there's a default perspective to fall back on
+        mw().SavePerspectives( _T("SpringLobby-default") );
+        mw().ShowConfigure();
+    }
+    else
+    {
+        mw().ShowSingleplayer();
+    }
+}
+
+
+void Ui::CheckForUpdates()
+{
+    wxString latestVersion = GetLatestVersion();
+
+    if (latestVersion == _T("-1"))
+    {
+        customMessageBoxNoModal(SL_MAIN_ICON, _("There was an error checking for the latest version.\nPlease try again later.\nIf the problem persists, please use Help->Report Bug to report this bug."), _("Error"));
+        return;
+    }
+	//get current rev w/o AUX_VERSION added
+	wxString myVersion = GetSpringLobbyVersion( false ) ;
+
+    wxString msg = _("Your Version: ") + myVersion + _T("\n") + _("Latest Version: ") + latestVersion;
+    if ( !latestVersion.IsSameAs(myVersion, false) )
+    {
+        #ifdef __WXMSW__
+        int answer = customMessageBox(SL_MAIN_ICON, _("Your SpringLobby version is not up to date.\n\n") + msg + _("\n\nWould you like for me to autodownload the new version? Changes will take effect next you launch the lobby again."), _("Not up to date"), wxYES_NO);
+        if (answer == wxYES)
+        {
+            wxString command = _T("\"") + wxPathOnly( wxStandardPaths::Get().GetExecutablePath() ) + wxFileName::GetPathSeparator() + _T("springlobby_updater.exe\"");
+            wxString params = _T("-f \"") + wxStandardPaths::Get().GetExecutablePath() + _T("\"") + _T(" -r ") +  latestVersion  ;
+            if( WinExecute( command, params ) > 0 ) {
+                //returned pid > 0 -> proc started successfully
+                // now close this instance immeadiately
+                wxCloseEvent dummy;
+                ui().mw().OnClose( dummy );
+            }
+            else
+            {//this will also happen if updater exe is not present so we don't really ne special check for existance of it
+                customMessageBox(SL_MAIN_ICON, _("Automatic update failed\n\nyou will be redirected to a web page with instructions and the download link will be opened in your browser.") + msg, _("Updater error.") );
+                OpenWebBrowser( _T("http://springlobby.info/wiki/springlobby/Install#Windows-Binary") );
+                OpenWebBrowser( GetDownloadUrl( latestVersion ) );
+
+            }
+        }
+        #else
+        customMessageBoxNoModal(SL_MAIN_ICON, _("Your SpringLobby version is not up to date.\n\n") + msg, _("Not up to Date") );
+        #endif
+    }
+    /* TODO currently not usable cause automatic update calls this function too and we don't want a msg box everytime the check succeeds
+    else
+        customMessageBoxNoModal(SL_MAIN_ICON, _("Your SpringLobby version is up to date.\n\n") + msg, _("Up to Date") );
+    */
 }
