@@ -2,7 +2,7 @@
 #define SPRINGLOBBY_UPDATER_H_INCLUDED
 
 #include <wx/event.h>
-
+#include "../httpdownloader.h"
 
 class UpdaterClass : public wxEvtHandler
 {
@@ -12,7 +12,7 @@ class UpdaterClass : public wxEvtHandler
     void CheckForUpdates();
 
 #ifdef __WXMSW__
-    void StartUpdate( const wxString& rev, bool fromCli = false );
+    bool StartUpdate( const wxString& latestVersion, const wxString& exe_to_update );
 #endif
     void OnDownloadEvent( wxCommandEvent& event );
 
@@ -21,14 +21,15 @@ protected:
     bool UpdateExe( const wxString& newexe, bool WaitForReboot );
     bool UpdateLocale( const wxString& newdir, bool WaitForReboot );
 
+    bool PostMinGW44( const wxString& newdir );
+
     wxString m_newexe;
+    wxString m_currentexe;
+    wxString m_latest_version;
+
+    HttpDownloaderThread<UpdaterClass>* m_http_thread;
 
     DECLARE_EVENT_TABLE()
-
-    wxString m_cur_mw_title;
-
-    bool m_fromCli;
-
 };
 
 UpdaterClass& Updater();
